@@ -35,7 +35,7 @@ namespace ARTICLE
     typedef sigc::signal< bool, GdkEventKey* > SIG_KEY_RELEASE;
     typedef sigc::signal< bool, GdkEventScroll* > SIG_SCROLL_EVENT;
 
-    typedef sigc::signal< void, std::string, int > SIG_ON_URL;
+    typedef sigc::signal< void, std::string, std::string, int > SIG_ON_URL;
     typedef sigc::signal< void > SIG_LEAVE_URL;
 
     struct URLINFO
@@ -228,6 +228,9 @@ namespace ARTICLE
         // セパレータが画面に表示されているか
         const bool is_separator_on_screen();
 
+        // 現在のポインタの下にあるレス番号取得
+        const int get_current_res_num();
+
         // 全選択
         void select_all(); 
 
@@ -250,14 +253,14 @@ namespace ARTICLE
         int max_number();   // 表示されている最後のレスの番号
 
         // レスをappendして再レイアウト
-        void append_res( int from_num, int to_num );
+        void append_res( const int from_num, const int to_num );
 
         // リストで指定したレスをappendして再レイアウト
-        void append_res( std::list< int >& list_resnum );
+        void append_res( const std::list< int >& list_resnum );
 
         // リストで指定したレスをappendして再レイアウト( 連結情報付き )
         // list_joint で連結指定したレスはヘッダを取り除いて前のレスに連結する
-        void append_res( std::list< int >& list_resnum, std::list< bool >& list_joint );
+        void append_res( const std::list< int >& list_resnum, const std::list< bool >& list_joint );
 
         // html をappendして再レイアウト
         void append_html( const std::string& html );
@@ -290,8 +293,8 @@ namespace ARTICLE
         void goto_back();
 
         // 検索
-        int search( std::list< std::string >& list_query, bool reverse );
-        int search_move( bool reverse );
+        const int search( const std::list< std::string >& list_query, const bool reverse );
+        const int search_move( const bool reverse );
         void clear_highlight();
 
         // 実況モード
@@ -314,7 +317,10 @@ namespace ARTICLE
         void set_colorid_back( int id ){ m_colorid_back = id; }
 
         // 共通セットアップ
-        void setup( bool show_abone, bool show_scrbar );
+        // show_abone : あぼーんされたスレも表示
+        // show_scrbar : スクロールバーを最初から表示
+        // show_multispace : 連続空白も表示
+        void setup( const bool show_abone, const bool show_scrbar, const bool show_multispace );
 
         // レイアウト処理
         virtual bool exec_layout();
@@ -357,6 +363,7 @@ namespace ARTICLE
 
         bool draw_one_node( LAYOUT* layout, const int width_win, const int pos_y, const int upper, const int lower );
         void draw_div( LAYOUT* layout_div, const int pos_y, const int upper, const int lower );
+        const bool get_selection_byte( const LAYOUT* layout, const SELECTION& selection, size_t& byte_from, size_t& byte_to );
         void draw_one_text_node( LAYOUT* layout, const int width_win, const int pos_y );
         void draw_string( LAYOUT* node, const int pos_y, const int width_view,
                           const int color, const int color_back, const int byte_from, const int byte_to );
