@@ -413,6 +413,7 @@ BBSListViewBase::BBSListViewBase( const std::string& url,const std::string& arg1
     "<separator/>" \
     "<menuitem action='PreferenceArticle'/>" \
     "<menuitem action='PreferenceBoard'/>" \
+    "<menuitem action='PreferenceImage'/>" \
     "</popup>"
 
     // 履歴 + 複数選択
@@ -551,6 +552,7 @@ const bool BBSListViewBase::set_command( const std::string& command, const std::
     if( command == "append_item" ) append_item();
     else if( command == "append_history" ) append_history();
     else if( command == "remove_item" ) remove_item( arg1 );
+    else if( command == "remove_headitem" ) remove_headitem();
     else if( command == "remove_allitems" ) remove_allitems();
     else if( command == "edit_tree" ) edit_tree();
     else if( command == "save_xml" ) save_xml(); 
@@ -1293,7 +1295,8 @@ void BBSListViewBase::slot_dropped_from_other( const CORE::DATA_INFO_LIST& list_
 
             case TYPE_IMAGE:
 
-                DBIMG::set_protect( info.url, true );
+                if( m_set_bookmark ) DBIMG::set_protect( info.url, true );
+                m_set_image.insert( info.url );
                 break;
         }
     }
@@ -1991,6 +1994,10 @@ void BBSListViewBase::open_selected_rows()
                 if( !list_url_article.empty() ) list_url_article += " ";
                 list_url_article += url;
                 break;
+
+            case TYPE_IMAGE:
+                if( ! DBIMG::get_abone( url ) ) CORE::core_set_command( "open_image", url );
+                break;
         }
     }
 
@@ -2249,6 +2256,7 @@ void BBSListViewBase::tree2xml( const std::string& root_name )
     // ルート要素に属性( path, y )の値を設定
     XML::Dom* root = m_document.get_root_element( root_name );
     if( root ){
+        if( ! m_date_modified.empty() ) root->setAttribute( "date_modified", m_date_modified );
         root->setAttribute( "y", y );
         root->setAttribute( "path", path );
     }
@@ -2281,7 +2289,8 @@ void BBSListViewBase::xml2tree( const std::string& root_name, const std::string&
     XML::Dom* root = m_document.get_root_element( root_name );
     if( root ){
 
-	// ルート要素から属性( path, y )の値を取得
+	// ルート要素から属性( date_modified, path, y )の値を取得
+	m_date_modified = root->getAttribute( "date_modified" );
 	std::string focused_path = root->getAttribute( "path" );
 	int y = atoi( root->getAttribute( "y" ).c_str() );
 
@@ -2330,6 +2339,7 @@ void BBSListViewBase::update_urls()
 
     m_set_board.clear();
     m_set_thread.clear();
+    m_set_image.clear();
     
     SKELETON::EditTreeViewIterator it( m_treeview, m_columns, Gtk::TreePath() );
     for( ; ! it.end(); ++it ){
@@ -2379,6 +2389,10 @@ void BBSListViewBase::update_urls()
 
                 m_set_thread.insert( url_new );
                 break;
+
+            case TYPE_IMAGE:
+                m_set_image.insert( url );
+                break;
         }
     }
 
@@ -2836,7 +2850,9 @@ void BBSListViewBase::append_history()
     // ツリーにアイテムが含まれている場合は削除
     // 履歴はサブディレクトリが無いと仮定してサブディレクトリの探査はしない
     if( ( ( *it_info ).type == TYPE_THREAD && m_set_thread.find_if( ( *it_info ).url ) ) 
-        || ( ( ( *it_info ).type == TYPE_BOARD || ( *it_info ).type == TYPE_VBOARD )  && m_set_board.find( ( *it_info ).url ) != m_set_board.end() ) ){
+        || ( ( ( *it_info ).type == TYPE_BOARD || ( *it_info ).type == TYPE_VBOARD )  && m_set_board.find( ( *it_info ).url ) != m_set_board.end() )
+        || ( ( *it_info ).type == TYPE_IMAGE && m_set_image.find( ( *it_info ).url ) != m_set_image.end() ) 
+        ){
 
         std::vector< Gtk::TreePath > del_path;
 
@@ -2954,6 +2970,7 @@ void BBSListViewBase::remove_item( const std::string& url )
 {
     std::string url_target = DBTREE::url_dat( url );
     if( url_target.empty() ) url_target = DBTREE::url_boardbase( url );
+    if( url_target.empty() && DBIMG::get_type_ext( url ) != DBIMG::T_UNKNOWN ) url_target = url;
     if( url_target.empty() ) return;
         
 #ifdef _DEBUG
@@ -2978,6 +2995,8 @@ void BBSListViewBase::remove_item( const std::string& url )
             case TYPE_THREAD_UPDATE:
             case TYPE_THREAD_OLD:
 
+            case TYPE_IMAGE: // 画像
+
                 if( url == url_target ){
 #ifdef _DEBUG
                     std::cout << "hit " << url << " == " << url_target << std::endl;
@@ -2994,6 +3013,27 @@ void BBSListViewBase::remove_item( const std::string& url )
 }
 
 
+//
+// 先頭項目を削除
+//
+void BBSListViewBase::remove_headitem()
+{
+    if( ! m_ready_tree ) return;
+    if( m_treestore->children().empty() ) return;
+
+#ifdef _DEBUG
+    std::cout << "BBSListViewBase::remove_headitem\n";
+#endif
+
+    std::list< Gtk::TreePath > list_path;
+    SKELETON::EditTreeViewIterator it( m_treeview, m_columns, Gtk::TreePath() );
+    list_path.push_back( it.get_path() );
+
+    const bool force = true;
+    m_treeview.delete_path( list_path, force );
+}
+
+
 //
 // 全項目を削除
 //
@@ -3006,6 +3046,7 @@ void BBSListViewBase::remove_allitems()
     m_treestore->clear();
     m_set_board.clear();
     m_set_thread.clear();
+    m_set_image.clear();
 }
 
 
