@@ -13,6 +13,8 @@
 #include "jdlib/miscutil.h"
 #include "jdlib/misctime.h"
 
+#include "config/globalconf.h"
+
 #include "cache.h"
 #include "command.h"
 #include "global.h"
@@ -27,6 +29,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
       m_entry_writemail( true, "メール：" ),
       m_check_noname( "名前欄が空白の時は書き込まない" ),
       m_bt_clear_post_history( "この板にある全スレの書き込み履歴クリア" ),
+      m_bt_set_default_namemail( "デフォルト" ),
 
       m_frame_cookie( "クッキーと書き込みキーワード" ),
       m_button_cookie( "削除" ) ,
@@ -49,16 +52,30 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
       m_button_clearmodified( "日時クリア" ),
       m_label_samba( false, "書き込み規制秒数 (Samba24) ：" ),
       m_button_clearsamba( "秒数クリア" ),
+      m_check_oldlog( "過去ログを表示する" ),
       m_button_remove_old_title( "dat落ちしたスレのタイトルを削除する" ),
       m_localrule( NULL )
 {
     m_edit_cookies.set_editable( false );
 
     // 書き込み設定
+    const int samba_sec = DBTREE::board_samba_sec( get_url() );
+    if( ! samba_sec ) m_label_samba.set_text( "未取得" );
+    else m_label_samba.set_text( MISC::itostr( samba_sec ) );
+
+    m_button_clearsamba.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_samba ) );
+    m_hbox_samba.pack_start( m_label_samba );
+    m_hbox_samba.pack_start( m_button_clearsamba, Gtk::PACK_SHRINK );    
+
     m_check_noname.set_active( DBTREE::board_check_noname( get_url() ) );
-    m_entry_writename.set_text(DBTREE::board_get_write_name( get_url() ) ); 
-    m_entry_writemail.set_text(DBTREE::board_get_write_mail( get_url() ) );
-    if( m_entry_writemail.get_text().empty() ) m_entry_writemail.set_text( "sage" );
+
+    m_entry_writename.set_text( DBTREE::board_get_write_name( get_url() ) ); 
+    if( m_entry_writename.get_text().empty() ) m_entry_writename.set_text( CONFIG::get_write_name() );
+    // JD_NAME_BLANK の場合空白をセットする
+    else if( m_entry_writename.get_text() == JD_NAME_BLANK ) m_entry_writename.set_text( std::string() );
+
+    m_entry_writemail.set_text( DBTREE::board_get_write_mail( get_url() ) );
+    if( m_entry_writemail.get_text().empty() ) m_entry_writemail.set_text( CONFIG::get_write_mail() );
     // JD_MAIL_BLANK の場合空白をセットする
     else if( m_entry_writemail.get_text() == JD_MAIL_BLANK ) m_entry_writemail.set_text( std::string() );
 
@@ -67,12 +84,16 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_hbox_write1.pack_start( m_check_noname );
     m_hbox_write1.pack_start( m_bt_clear_post_history );
 
+    m_bt_set_default_namemail.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_set_default_namemail ) );
+
     m_hbox_write2.set_spacing( 8 );
     m_hbox_write2.pack_start( m_entry_writename );
+    m_hbox_write2.pack_end( m_bt_set_default_namemail, Gtk::PACK_SHRINK );
     m_hbox_write2.pack_end( m_entry_writemail, Gtk::PACK_SHRINK );
 
     m_vbox_write.set_border_width( 8 );
     m_vbox_write.set_spacing( 8 );
+    m_vbox_write.pack_start( m_hbox_samba,  Gtk::PACK_SHRINK );
     m_vbox_write.pack_start( m_hbox_write1, Gtk::PACK_SHRINK );
     m_vbox_write.pack_start( m_hbox_write2, Gtk::PACK_SHRINK );
 
@@ -84,15 +105,16 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     // cookie と 書き込みキーワード の設定
     std::string str_cookies;
     std::list< std::string > list_cookies = DBTREE::board_list_cookies_for_write( get_url() );
-    if( list_cookies.empty() ) str_cookies = "cookie: 未取得\n";
+    if( list_cookies.empty() ) str_cookies = "クッキー:\n未取得\n";
     else{
+        str_cookies = "クッキー:\n";
         std::list< std::string >::iterator it = list_cookies.begin();
         for( ; it != list_cookies.end(); ++it )
-            str_cookies += "cookie: " + MISC::Iconv( (*it), DBTREE::board_charset( get_url() ), "UTF-8" ) + "\n";
+            str_cookies += MISC::Iconv( (*it), DBTREE::board_charset( get_url() ), "UTF-8" ) + "\n";
     }
 
     const std::string keyword = DBTREE::board_keyword_for_write( get_url() );
-    if( ! keyword.empty() ) str_cookies += "\nkeyword: " + keyword + "\n";
+    if( ! keyword.empty() ) str_cookies += "\nキーワード: " + keyword + "\n";
 
     m_edit_cookies.set_text( str_cookies );
 
@@ -164,13 +186,13 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_hbox_modified.pack_start( m_label_modified );
     m_hbox_modified.pack_start( m_button_clearmodified, Gtk::PACK_SHRINK );    
 
-    const int samba_sec = DBTREE::board_samba_sec( get_url() );
-    if( ! samba_sec ) m_label_samba.set_text( "未取得" );
-    else m_label_samba.set_text( MISC::itostr( samba_sec ) );
+    // 過去ログ表示
+    if( CONFIG::get_show_oldarticle() ){
 
-    m_button_clearsamba.signal_clicked().connect( sigc::mem_fun(*this, &Preferences::slot_clear_samba ) );
-    m_hbox_samba.pack_start( m_label_samba );
-    m_hbox_samba.pack_start( m_button_clearsamba, Gtk::PACK_SHRINK );    
+        m_check_oldlog.set_active( true );
+        m_check_oldlog.set_sensitive( false );
+    }
+    else m_check_oldlog.set_active( DBTREE::board_show_oldlog( get_url() ) );
 
     m_vbox.set_border_width( 16 );
     m_vbox.set_spacing( 8 );
@@ -183,7 +205,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_vbox.pack_start( m_label_last_access, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_hbox_modified, Gtk::PACK_SHRINK );
     m_vbox.pack_start( m_hbox_live, Gtk::PACK_SHRINK );
-    m_vbox.pack_start( m_hbox_samba, Gtk::PACK_SHRINK );
+    m_vbox.pack_start( m_check_oldlog, Gtk::PACK_SHRINK );
     m_vbox.pack_end( m_frame_cookie, Gtk::PACK_SHRINK );
     m_vbox.pack_end( m_frame_write, Gtk::PACK_SHRINK );
 
@@ -321,6 +343,7 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     m_edit_settingtxt.set_text( DBTREE::settingtxt( get_url() ) );
 
     m_notebook.append_page( m_vbox, "一般" );
+    const int page_localrule = 1;
     m_notebook.append_page( *m_localrule, "ローカルルール" );
     m_notebook.append_page( m_vbox_proxy, "プロキシ設定" );
     const int page_abone_article = 3;
@@ -334,7 +357,8 @@ Preferences::Preferences( Gtk::Window* parent, const std::string& url, const std
     resize( 600, 400 );
     show_all_children();
 
-    if( command == "show_abone_article" ) m_notebook.set_current_page( page_abone_article );
+    if( command == "show_localrule" ) m_notebook.set_current_page( page_localrule );
+    else if( command == "show_abone_article" ) m_notebook.set_current_page( page_abone_article );
 }
 
 
@@ -381,12 +405,19 @@ void Preferences::slot_clear_post_history()
 }
 
 
+void Preferences::slot_set_default_namemail()
+{
+    m_entry_writename.set_text( CONFIG::get_write_name() );
+    m_entry_writemail.set_text( CONFIG::get_write_mail() );
+}
+
+
 void Preferences::slot_delete_cookie()
 {
-    DBTREE::board_set_list_cookies_for_write( get_url(), std::list< std::string >() );
+    DBTREE::board_reset_list_cookies_for_write( get_url() );
     DBTREE::board_set_keyword_for_write( get_url(), std::string() );
 
-    m_edit_cookies.set_text( "未取得" );
+    m_edit_cookies.set_text( "クッキー:\n未取得\n" );
 }
 
 
@@ -449,6 +480,32 @@ void Preferences::slot_ok_clicked()
     DBTREE::board_set_local_proxy_w( get_url(), MISC::remove_space( m_proxy_frame_w.entry_host.get_text() ) );
     DBTREE::board_set_local_proxy_port_w( get_url(), atoi( m_proxy_frame_w.entry_port.get_text().c_str() ) );
 
+    // 書き込み設定
+    DBTREE::board_set_check_noname( get_url(), m_check_noname.get_active() );
+
+    std::string tmpname = m_entry_writename.get_text();
+    if( tmpname == CONFIG::get_write_name() ) tmpname = std::string();
+    else if( tmpname.empty() ) tmpname = JD_NAME_BLANK; // 空白の場合 JD_NAME_BLANK をセットする
+    DBTREE::board_set_write_name( get_url(), tmpname );
+
+    std::string tmpmail = m_entry_writemail.get_text();
+    if( tmpmail == CONFIG::get_write_mail() ) tmpmail = std::string();
+    else if( tmpmail.empty() ) tmpmail = JD_MAIL_BLANK; // 空白の場合 JD_MAIL_BLANK をセットする
+    DBTREE::board_set_write_mail( get_url(), tmpmail );
+
+    // 実況間隔
+    int live_sec = 0;
+    if( m_check_live.get_active() ) live_sec = m_spin_live.get_value_as_int();
+    DBTREE::board_set_live_sec( get_url(), live_sec );
+    CORE::core_set_command( "redraw_article_toolbar" );
+
+    // 最大レス数
+    const int number_max_res = m_spin_maxres.get_value_as_int();
+    DBTREE::board_set_number_max_res( get_url(), number_max_res );
+
+    // 過去ログ表示
+    if( ! CONFIG::get_show_oldarticle() ) DBTREE::board_set_show_oldlog( get_url(), m_check_oldlog.get_active() );
+
     // あぼーん再設定
     std::list< std::string > list_id = MISC::get_lines( m_edit_id.get_text() );
     std::list< std::string > list_name = MISC::get_lines( m_edit_name.get_text() );
@@ -462,27 +519,10 @@ void Preferences::slot_ok_clicked()
     std::list< std::string > list_regex_thread = MISC::get_lines( m_edit_regex_thread.get_text() );
     const int number = m_spin_number.get_value_as_int();
     const int hour = m_spin_hour.get_value_as_int();
-    const bool redraw = true; // スレ一覧を再描画
+
+    const bool redraw = true; // ここでスレ一覧の再描画指定をする
     DBTREE::reset_abone_thread( get_url(), list_thread, list_word_thread, list_regex_thread, number, hour, redraw );  
 
-    // 書き込み設定
-    DBTREE::board_set_check_noname( get_url(), m_check_noname.get_active() );
-    DBTREE::board_set_write_name( get_url(), m_entry_writename.get_text() );
-
-    std::string tmpmail = m_entry_writemail.get_text();
-    if( tmpmail.empty() ) tmpmail = JD_MAIL_BLANK; // 空白の場合 JD_MAIL_BLANK をセットする
-    DBTREE::board_set_write_mail( get_url(), tmpmail );
-
-    // 実況間隔
-    int live_sec = 0;
-    if( m_check_live.get_active() ) live_sec = m_spin_live.get_value_as_int();
-    DBTREE::board_set_live_sec( get_url(), live_sec );
-    CORE::core_set_command( "redraw_article_toolbar" );
-
-    // 最大レス数
-    const int number_max_res = m_spin_maxres.get_value_as_int();
-    DBTREE::board_set_number_max_res( get_url(), number_max_res );
-
     DBTREE::board_save_info( get_url() );
 }
 
