@@ -5,9 +5,23 @@
 #ifndef _CACHE_H
 #define _CACHE_H
 
-#include <stdint.h>
+#include <glib.h>
 #include <string>
 #include <list>
+#include <ctime>
+
+#ifdef _WIN32
+#define ENV_HOME "USERPROFILE"
+#else
+#define ENV_HOME "HOME"
+#endif
+
+// UTF-8からロケールでエンコードされた文字列に変換
+#ifdef _WIN32
+#define to_locale_cstr( path ) Glib::locale_from_utf8((path)).c_str()
+#else
+#define to_locale_cstr( path ) (path).c_str()
+#endif
 
 namespace Gtk
 {
@@ -23,6 +37,7 @@ namespace CACHE
 
     // 設定ファイル
     std::string path_conf();
+    std::string path_conf_bkup();
     std::string path_conf_old();  // 旧ファイル
 
     // セッション情報ファイル
@@ -59,15 +74,18 @@ namespace CACHE
 
     // スレ履歴
     std::string path_xml_history();
-    std::string path_xml_history_old();
 
     // 板履歴
     std::string path_xml_history_board();
-    std::string path_xml_history_board_old();
 
     // 最近閉じたスレの履歴
     std::string path_xml_history_close();
-    std::string path_xml_history_close_old();
+
+    // 最近閉じた板の履歴
+    std::string path_xml_history_closeboard();
+
+    // 最近閉じた画像の履歴
+    std::string path_xml_history_closeimg();
 
     // View履歴
     std::string path_xml_history_view();
@@ -113,15 +131,24 @@ namespace CACHE
     std::string path_aadir();  // アスキーアートファイル格納用ディレクトリ .jd/aa/
     std::string path_aahistory();  // AAの使用履歴ファイル
 
+    // テーマのルートパス
+    const std::string path_theme_root();
+
+    // アイコンテーマのルートパス
+    const std::string path_theme_icon_root();
+
     // css
     std::string path_css();
+    std::string path_css_old();
 
     // html
     std::string path_reshtml();
+    std::string path_reshtml_old();
 
     // ログ
     std::string path_logroot();
     std::string path_postlog(); // 書き込みログ
+    std::string path_msglog(); // メッセージログ（-lオプション）
 
     // 検索や名前などの補完情報
     std::string path_completion( int mode );
@@ -169,6 +196,7 @@ namespace CACHE
     const int file_exists( const std::string& path );
     size_t get_filesize( const std::string& path );
     time_t get_filemtime( const std::string& path );
+    const bool set_filemtime( const std::string& path, const time_t mtime );
 
     // ファイル操作
     bool jdmkdir( const std::string& path );
@@ -195,7 +223,7 @@ namespace CACHE
     std::list< std::string > get_filelist( const std::string& dir );
 
     // dir ディレクトリ内のレギュラーファイルの合計サイズを取得
-    int64_t get_dirsize( const std::string& dir );
+    guint64 get_dirsize( const std::string& dir );
 
     // 相対パスから絶対パスを取得してファイルが存在すれば絶対パスを返す
     // ファイルが存在しない場合は std::string() を返す
