@@ -169,6 +169,13 @@ const bool ConfigItems::load( const bool restore )
     // 同一ホストに対する最大コネクション数( 1 または 2 )
     connection_num = cf.get_option_int( "connection_num", CONF_CONNECTION_NUM, 1, 2 );
 
+    // 2chのクッキー:HAPを保存する
+    use_cookie_hap = cf.get_option_bool( "use_cookie_hap", CONF_USE_COOKIE_HAP );
+
+    // 2chのクッキー:HAP
+    cookie_hap = cf.get_option_str( "cookie_hap", CONF_COOKIE_HAP );
+    cookie_hap_bbspink = cf.get_option_str( "cookie_hap_bbspink", CONF_COOKIE_HAP_BBSPINK );
+
     // ブラウザ設定ダイアログのコンボボックスの番号
     browsercombo_id = cf.get_option_int( "browsercombo_id", CONF_BROWSER_NO, 0, CORE::get_browser_number() -1 );
 
@@ -209,6 +216,9 @@ const bool ConfigItems::load( const bool restore )
     embimg_width = cf.get_option_int( "embimg_width", CONF_EMBIMG_WIDTH, 16, 8192 );
     embimg_height = cf.get_option_int( "embimg_height", CONF_EMBIMG_HEIGHT, 16, 8192 );
 
+    // 埋め込み画像ビューを閉じたときにタブも閉じる
+    hide_imagetab = cf.get_option_bool( "hide_imagetab", CONF_HIDE_IMAGETAB );
+
     // 画像ビューでdeleteを押したときに確認ダイアログを表示する
     show_delimgdiag = cf.get_option_bool( "show_delimgdiag", CONF_SHOW_DELIMGDIAG );
 
@@ -245,6 +255,9 @@ const bool ConfigItems::load( const bool restore )
     // p2の認証サーバのアドレス
     url_loginp2 = cf.get_option_str( "url_loginp2", CONF_LOGINP2 );
 
+    // BEの認証サーバのアドレス
+    url_loginbe = cf.get_option_str( "url_loginbe", CONF_LOGINBE );
+
     // bbsmenu.htmlのURL
     url_bbsmenu = cf.get_option_str( "url_bbsmenu", CONF_URL_BBSMENU );
 
@@ -344,6 +357,12 @@ const bool ConfigItems::load( const bool restore )
     // お気に入りでカテゴリを常にひとつだけ開く
     open_one_favorite = cf.get_option_bool( "open_one_favorite", CONF_OPEN_ONE_FAVORITE );
 
+    // デフォルトの書き込み名
+    write_name = cf.get_option_str( "write_name", CONF_WRITE_NAME );
+
+    // デフォルトのメールアドレス
+    write_mail = cf.get_option_str( "write_mail", CONF_WRITE_MAIL );
+
     // 書き込み時に書き込み確認ダイアログを出さない
     always_write_ok = cf.get_option_bool( "always_write_ok", CONF_ALWAYS_WRITE_OK );
 
@@ -413,6 +432,9 @@ const bool ConfigItems::load( const bool restore )
     instruct_tglimg = cf.get_option_bool( "instruct_tglimg", CONF_INSTRUCT_TGLIMG );
     instruct_tglimg_end = false;
 
+    // スレビューでdeleteを押したときに確認ダイアログを表示する
+    show_delartdiag = cf.get_option_bool( "show_delartdiag", CONF_SHOW_DELARTDIAG );
+
     // 下線位置
     adjust_underline_pos = cf.get_option_double( "adjust_underline_pos", ( double )CONF_ADJUST_UNDERLINE_POS, ( double )0, ( double )64 );
 
@@ -451,6 +473,9 @@ const bool ConfigItems::load( const bool restore )
     // タブにアイコンを表示するか
     show_tab_icon = cf.get_option_bool( "show_tab_icon", CONF_SHOW_TAB_ICON );
 
+    // タブ上でマウスホイールを回転してタブを切り替える
+    switchtab_wheel = cf.get_option_bool( "switchtab_wheel", CONF_SWITCHTAB_WHEEL );
+
     // スレビューに書き込みマークを表示するか
     show_post_mark = cf.get_option_bool( "show_post_mark", CONF_SHOW_POST_MARK );
 
@@ -496,6 +521,10 @@ const bool ConfigItems::load( const bool restore )
     abone_transparent = cf.get_option_bool( "abone_transparent", CONF_ABONE_TRANSPARENT );
     abone_chain = cf.get_option_bool( "abone_chain", CONF_ABONE_CHAIN );
 
+    // NG正規表現によるあぼーん時に大小と全半角文字の違いを無視
+    abone_icase = cf.get_option_bool( "abone_icase", CONF_ABONE_ICASE );
+    abone_wchar = cf.get_option_bool( "abone_wchar", CONF_ABONE_WCHAR );
+
     // 右ペーンが空の時にサイドバーを閉じるか
     expand_sidebar = cf.get_option_bool( "expand_sidebar", CONF_EXPAND_SIDEBAR );
 
@@ -535,6 +564,9 @@ const bool ConfigItems::load( const bool restore )
     // メニューバーを非表示にした時にダイアログを表示
     show_hide_menubar_diag = cf.get_option_bool( "show_hide_menubar_diag", CONF_SHOW_HIDE_MENUBAR_DIAG );
 
+    // 状態変更時にメインステータスバーの色を変える
+    change_stastatus_color = cf.get_option_bool( "change_stastatus_color", CONF_CHANGE_STASTATUS_COLOR );
+
     // まちBBSの取得に offlaw.cgi を使用する
     use_machi_offlaw = cf.get_option_bool( "use_machi_offlaw", CONF_USE_MACHI_OFFLAW );
 
@@ -615,6 +647,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "url_jdhp", url_jdhp );
     cf.update( "url_login2ch", url_login2ch );
     cf.update( "url_loginp2", url_loginp2 );
+    cf.update( "url_loginbe", url_loginbe );
     cf.update( "url_bbsmenu", url_bbsmenu );
     cf.update( "use_link_as_board", use_link_as_board );
     cf.update( "show_movediag", show_movediag );
@@ -673,6 +706,10 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "use_ipv6", use_ipv6 );
     cf.update( "connection_num", connection_num );
 
+    cf.update( "use_cookie_hap", use_cookie_hap );
+    cf.update( "cookie_hap", cookie_hap );
+    cf.update( "cookie_hap_bbspink", cookie_hap_bbspink );
+
     cf.update( "command_openurl", command_openurl );
     cf.update( "browsercombo_id", browsercombo_id );
 
@@ -691,6 +728,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "show_ssspicon", show_ssspicon );
     cf.update( "embimg_width", embimg_width );
     cf.update( "embimg_height", embimg_height );
+    cf.update( "hide_imagetab", hide_imagetab );
     cf.update( "show_delimgdiag", show_delimgdiag );
     cf.update( "use_mosaic", use_mosaic );
     cf.update( "mosaic_size", mosaic_size );
@@ -709,6 +747,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "cl_char_selection", str_color[ COLOR_CHAR_SELECTION ] );
     cf.update( "cl_char_highlight", str_color[ COLOR_CHAR_HIGHLIGHT ] );
     cf.update( "cl_char_link", str_color[ COLOR_CHAR_LINK ] );
+    cf.update( "cl_char_link_id_low", str_color[ COLOR_CHAR_LINK_ID_LOW ] );
+    cf.update( "cl_char_link_id_high", str_color[ COLOR_CHAR_LINK_ID_HIGH ] );
+    cf.update( "cl_char_link_res", str_color[ COLOR_CHAR_LINK_RES ] );
     cf.update( "cl_char_link_low", str_color[ COLOR_CHAR_LINK_LOW ] );
     cf.update( "cl_char_link_high", str_color[ COLOR_CHAR_LINK_HIGH ] );
     cf.update( "cl_char_message", str_color[ COLOR_CHAR_MESSAGE ] );
@@ -768,6 +809,9 @@ void ConfigItems::save_impl( const std::string& path )
 
     cf.update( "open_one_category", open_one_category );
     cf.update( "open_one_favorite", open_one_favorite );
+
+    cf.update( "write_mail", write_mail );
+    cf.update( "write_name", write_name );
     cf.update( "always_write_ok", always_write_ok );
     cf.update( "save_postlog", save_postlog );
     cf.update( "maxsize_postlog", maxsize_postlog );
@@ -791,6 +835,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "instruct_popup", instruct_popup );
     cf.update( "instruct_tglart", instruct_tglart );
     cf.update( "instruct_tglimg", instruct_tglimg );
+    cf.update( "show_delartdiag", show_delartdiag );
 
     cf.update( "adjust_underline_pos", adjust_underline_pos );
     cf.update( "adjust_line_space", adjust_line_space );
@@ -812,6 +857,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "tab_min_str", tab_min_str );
 
     cf.update( "show_tab_icon", show_tab_icon );
+
+    cf.update( "switchtab_wheel", switchtab_wheel );
+
     cf.update( "show_post_mark", show_post_mark );
 
     cf.update( "flat_button", flat_button );
@@ -842,6 +890,9 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "abone_transparent", abone_transparent );
     cf.update( "abone_chain", abone_chain );
 
+    cf.update( "abone_icase", abone_icase );
+    cf.update( "abone_wchar", abone_wchar );
+
     cf.update( "expand_sidebar", expand_sidebar );
     cf.update( "expand_rpane", expand_rpane );
 
@@ -857,6 +908,7 @@ void ConfigItems::save_impl( const std::string& path )
     cf.update( "show_favorite_select_diag", show_favorite_select_diag );
     cf.update( "disable_close", disable_close );
     cf.update( "show_hide_menubar_diag", show_hide_menubar_diag );
+    cf.update( "change_stastatus_color", change_stastatus_color );
     cf.update( "use_machi_offlaw", use_machi_offlaw );
     cf.update( "show_del_written_thread_diag", show_del_written_thread_diag );
     cf.update( "delete_img_in_thread", delete_img_in_thread );
@@ -935,13 +987,22 @@ void ConfigItems::set_colors( JDLIB::ConfLoader& cf )
     // ハイライトの文字色
     str_color[ COLOR_CHAR_HIGHLIGHT ] = cf.get_option_str( "cl_char_highlight", CONF_COLOR_CHAR_HIGHLIGHT, 13 );
 
-    // リンク(通常)の文字色
+    // 通常のリンクの文字色
     str_color[ COLOR_CHAR_LINK ] = cf.get_option_str( "cl_char_link", CONF_COLOR_CHAR_LINK, 13 );
 
-    // リンク(複数)の文字色
+    // 複数発言したIDの文字色
+    str_color[ COLOR_CHAR_LINK_ID_LOW ] = cf.get_option_str( "cl_char_link_id_low", CONF_COLOR_CHAR_LINK_ID_LOW, 13 );
+
+    // 多く発言したIDの文字色
+    str_color[ COLOR_CHAR_LINK_ID_HIGH ] = cf.get_option_str( "cl_char_link_id_high", CONF_COLOR_CHAR_LINK_ID_HIGH, 13 );
+
+    // 参照されていないレス番号の文字色
+    str_color[ COLOR_CHAR_LINK_RES ] = cf.get_option_str( "cl_char_link_res", CONF_COLOR_CHAR_LINK_RES, 13 );
+
+    // 他のレスから参照されたレス番号の文字色
     str_color[ COLOR_CHAR_LINK_LOW ] = cf.get_option_str( "cl_char_link_low", CONF_COLOR_CHAR_LINK_LOW, 13 );
 
-    // リンク(多数)の文字色
+    // 参照された数が多いレス番号の文字色
     str_color[ COLOR_CHAR_LINK_HIGH ] = cf.get_option_str( "cl_char_link_high", CONF_COLOR_CHAR_LINK_HIGH, 13 );
 
     // メッセージビューの文字色
