@@ -90,6 +90,13 @@ namespace CONFIG
         // 同一ホストに対する最大コネクション数( 1 または 2 )
         int connection_num;
 
+        // 2chのクッキー:HAPを保存する
+        bool use_cookie_hap;
+
+        // 2chのクッキー:HAP
+        std::string cookie_hap;
+        std::string cookie_hap_bbspink;
+
         // リンクをクリックしたときに実行するコマンド
         std::string command_openurl;
 
@@ -130,6 +137,9 @@ namespace CONFIG
         int embimg_width;
         int embimg_height;
 
+        // 埋め込み画像ビューを閉じたときにタブも閉じる
+        bool hide_imagetab;
+
         // 画像ビューでdeleteを押したときに確認ダイアログを表示する
         bool show_delimgdiag;
 
@@ -168,6 +178,9 @@ namespace CONFIG
         // p2の認証サーバのアドレス
         std::string url_loginp2;
 
+        // BEの認証サーバのアドレス
+        std::string url_loginbe;
+
         // bbsmenu.htmlのURL
         std::string url_bbsmenu;
 
@@ -270,6 +283,12 @@ namespace CONFIG
         // お気に入りでカテゴリを常にひとつだけ開く
         bool open_one_favorite;
 
+        // デフォルトの書き込み名
+        std::string write_name;
+
+        // デフォルトのメールアドレス
+        std::string write_mail;
+
         // 書き込み時に書き込み確認ダイアログを出さない
         bool always_write_ok;
 
@@ -339,6 +358,9 @@ namespace CONFIG
         bool instruct_tglimg;
         bool instruct_tglimg_end;
 
+        // スレビューでdeleteを押したときに確認ダイアログを表示する
+        bool show_delartdiag;
+
         // 下線位置
         double adjust_underline_pos;
 
@@ -377,6 +399,9 @@ namespace CONFIG
         // タブにアイコンを表示するか
         bool show_tab_icon;
 
+        // タブ上でマウスホイールを回転してタブを切り替える
+        bool switchtab_wheel;
+
         // スレビューに書き込みマークを表示するか
         bool show_post_mark;
 
@@ -414,6 +439,10 @@ namespace CONFIG
         bool abone_transparent;
         bool abone_chain;
 
+        // NG正規表現によるあぼーん時に大小と全半角文字の違いを無視
+        bool abone_icase;
+        bool abone_wchar;
+
         // 右ペーンが空の時にサイドバーを閉じるか
         bool expand_sidebar;
 
@@ -453,6 +482,9 @@ namespace CONFIG
         // メニューバーを非表示にした時にダイアログを表示
         bool show_hide_menubar_diag;
 
+        // 状態変更時にメインステータスバーの色を変える
+        bool change_stastatus_color;
+
         // まちBBSの取得に offlaw.cgi を使用する
         bool use_machi_offlaw;
 
