@@ -16,7 +16,11 @@ namespace CONFIG
         CONF_RESTORE_BOARD = 0,     // スレ一覧を復元
         CONF_RESTORE_ARTICLE = 0,   // スレを復元
         CONF_RESTORE_IMAGE = 0,     // 画像を復元
+#ifndef _WIN32
         CONF_MANAGE_WINPOS = 1,    // 自前でウィンドウ配置を管理する
+#else
+        CONF_MANAGE_WINPOS = 0,    // Windowsがウインドウ配置を管理する
+#endif
         CONF_REF_PREFIX_SPACE = 1, // 参照文字( CONF_REF_PREFIX ) の後のスペースの数
         CONF_USE_PROXY_FOR2CH = 0, // 2ch 読み込み用プロクシを使用するか
         CONF_PROXY_PORT_FOR2CH = 8080, // 2ch 読み込み用プロクシポート番号
@@ -32,6 +36,7 @@ namespace CONFIG
         CONF_LOADER_TIMEOUT_CHECKUPDATE = 10,  // 更新チェックのタイムアウト値
         CONF_USE_IPV6 = 1,          // ipv6使用
         CONF_CONNECTION_NUM = 2,    // 同一ホストに対する最大コネクション数( 1 または 2 )
+        CONF_USE_COOKIE_HAP = 1,    // 2chのクッキー:HAPを保存する
         CONF_REFPOPUP_BY_MO = 0,    // レス番号の上にマウスオーバーしたときに参照ポップアップ表示する
         CONF_NAMEPOPUP_BY_MO = 0,   // 名前の上にマウスオーバーしたときにポップアップ表示する
         CONF_IDPOPUP_BY_MO = 0,     // IDの上にマウスオーバーしたときにIDをポップアップ表示する
@@ -82,6 +87,7 @@ namespace CONFIG
         CONF_INSTRUCT_POPUP = 100,  // 0以上なら多重ポップアップの説明を表示する
         CONF_INSTRUCT_TGLART = 1, // スレビューを開いたときにスレ一覧との切り替え方法を説明する
         CONF_INSTRUCT_TGLIMG = 1, // 画像ビューを開いたときにスレビューとの切り替え方法を説明する
+        CONF_SHOW_DELARTDIAG = 1, // スレビューでdeleteを押したときに確認ダイアログを表示する
         CONF_ADJUST_UNDERLINE_POS = 1, // 下線位置
         CONF_ADJUST_LINE_SPACE = 1,    // 行間スペース
         CONF_DRAW_UNDERLINE = 1,     // リンク下線を表示
@@ -96,6 +102,7 @@ namespace CONFIG
         CONF_RELOAD_ALLTHREAD = 0,  // スレビューで再読み込みボタンを押したときに全タブを更新する
         CONF_TAB_MIN_STR = 4, // タブに表示する文字列の最小値
         CONF_SHOW_TAB_ICON = 1, // タブにアイコンを表示するか
+        CONF_SWITCHTAB_WHEEL = 1, // タブ上でマウスホイールを回転してタブを切り替える
         CONF_SHOW_POST_MARK = 1, // スレビューに書き込みマークを表示するか
         CONF_FLAT_BUTTON = 1,    // ボタンをフラットにするか
         CONF_DRAW_TOOLBARBACK = 0, // ツールバーの背景描画
@@ -110,6 +117,7 @@ namespace CONFIG
         CONF_SHOW_SSSPICON = 1,     // sssp アイコン表示
         CONF_EMBIMG_WIDTH = 100, // インライン画像の最大幅
         CONF_EMBIMG_HEIGHT = 100, // インライン画像の最大高さ
+        CONF_HIDE_IMAGETAB = 1,   // 埋め込み画像ビューを閉じたときにタブも閉じる
         CONF_SHOW_DELIMGDIAG = 1 ,     // 画像ビューでdeleteを押したときに確認ダイアログを表示する
         CONF_USE_MOSAIC = 1,        // 画像にモザイクをかける
         CONF_MOSAIC_SIZE = 60,        // モザイクの大きさ
@@ -126,6 +134,8 @@ namespace CONFIG
         CONF_ABONE_HOUR_THREAD = 0,   // スレあぼーん( スレ立てからの経過時間 )
         CONF_ABONE_TRANSPARENT = 0, // デフォルトで透明あぼーんをする
         CONF_ABONE_CHAIN = 0,       // デフォルトで連鎖あぼーんをする
+        CONF_ABONE_ICASE = 0,       // NG正規表現によるあぼーん時に大小文字の違いを無視
+        CONF_ABONE_WCHAR = 0,       // NG正規表現によるあぼーん時に全角半角文字の違いを無視
         CONF_EXPAND_SIDEBAR = 0,      // 右ペーンが空の時にサイドバーを閉じる
         CONF_EXPAND_RPANE = 1,        // 3ペーン時にスレ一覧やスレビューを最大化する
         CONF_OPEN_SIDEBAR_BY_CLICK = 1, // ペーンの境界をクリックしてサイドバーを開け閉めする
@@ -139,6 +149,7 @@ namespace CONFIG
         CONF_SHOW_FAVORITE_SELECT_DIAG = 0, // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
         CONF_DISABLE_CLOSE = 0, // Ctrl+qでウィンドウを閉じない
         CONF_SHOW_HIDE_MENUBAR_DIAG = 1, // メニューバーを非表示にした時にダイアログを表示
+        CONF_CHANGE_STASTATUS_COLOR = 1, // 状態変更時にメインステータスバーの色を変える
         CONF_USE_MACHI_OFFLAW = 0, // まちBBSの取得に offlaw.cgi を使用する
         CONF_SHOW_DEL_WRITTEN_THREAD_DIAG = 1, // 書き込み履歴のあるスレを削除する時にダイアログを表示
         CONF_DELETE_IMG_IN_THREAD = 0, // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
@@ -149,15 +160,17 @@ namespace CONFIG
 // browsers.cpp のデフォルトのラベル番号
 // configure で --with-xdg-open を指定すると xdg-open をデフォルトにする
 // browsers.cpp のブラウザの順番に気をつけること
+    enum{
+#ifndef _WIN32
 #ifdef XDGOPEN
-    enum{
         CONF_BROWSER_NO = 1  // xdg-open をデフォルトにする
-    };
 #else
-    enum{
         CONF_BROWSER_NO = 2  // firefox をデフォルトにする
+#endif
+#else /* _WIN32 */
+        CONF_BROWSER_NO = 1  // ie をデフォルトにする
+#endif /* _WIN32 */
     };
-#endif        
 
 #define CONF_FONTSIZE_THREAD "12"
 #define CONF_FONTSIZE_POPUP  "10"
@@ -187,6 +200,9 @@ namespace CONFIG
 // p2の認証サーバのアドレス
 #define CONF_LOGINP2 "http://p2.2ch.net/p2/"
 
+// BEの認証サーバのアドレス
+#define CONF_LOGINBE "http://be.2ch.net/test/login.php"
+
 // bbsmenu.htmlのURL
 #define CONF_URL_BBSMENU "http://menu.2ch.net/bbsmenu.html"
 
@@ -206,6 +222,10 @@ namespace CONFIG
 #define CONF_URL_WRITEP2 "http://p2.2ch.net/p2/post_form.php?host=$HOST&bbs=$BBSNAME&key=$DATNAME"
 #define CONF_URL_RESP2 "http://p2.2ch.net/p2/post_form.php?host=$HOST&bbs=$BBSNAME&key=$DATNAME&popup=1&inyou=2&resnum=$NUMBER"
 
+// 2chのクッキー:HAP
+#define CONF_COOKIE_HAP ""
+#define CONF_COOKIE_HAP_BBSPINK ""
+
 // 色
 #define CONF_COLOR_CHAR    "#000000000000"     // スレの文字
 #define CONF_COLOR_CHAR_NAME "#000064640000"   //名前欄の文字色
@@ -214,9 +234,12 @@ namespace CONFIG
 #define CONF_COLOR_CHAR_AGE "#fde800000000"    // ageの時のメール欄の文字色
 #define CONF_COLOR_CHAR_SELECTION "#ffffffffffff"  // 選択範囲の文字色
 #define CONF_COLOR_CHAR_HIGHLIGHT CONF_COLOR_CHAR  // ハイライトの文字色
-#define CONF_COLOR_CHAR_LINK "#00000000ffff" //リンク(通常)の文字色
-#define CONF_COLOR_CHAR_LINK_LOW "#ffff0000ffff" // リンク(複数)の文字色
-#define CONF_COLOR_CHAR_LINK_HIGH CONF_COLOR_CHAR_AGE  // リンク(多数)の文字色
+#define CONF_COLOR_CHAR_LINK "#00000000ffff" //通常のリンクの文字色
+#define CONF_COLOR_CHAR_LINK_ID_LOW  CONF_COLOR_CHAR_LINK // 複数発言したIDの文字色
+#define CONF_COLOR_CHAR_LINK_ID_HIGH CONF_COLOR_CHAR_AGE // 多く発言したIDの文字色
+#define CONF_COLOR_CHAR_LINK_RES CONF_COLOR_CHAR_LINK // 参照されていないレス番号の文字色
+#define CONF_COLOR_CHAR_LINK_LOW "#ffff0000ffff" // 他のレスから参照されたレス番号の文字色
+#define CONF_COLOR_CHAR_LINK_HIGH CONF_COLOR_CHAR_AGE  // 参照された数が多いレス番号の文字色
 #define CONF_COLOR_CHAR_MESSAGE CONF_COLOR_CHAR  // メッセージビューの文字色
 #define CONF_COLOR_CHAR_MESSAGE_SELECTION CONF_COLOR_CHAR_SELECTION  // メッセージビュー(選択範囲)の文字色
 
@@ -249,6 +272,9 @@ namespace CONFIG
 #define CONF_COLOR_BACK_BOARD CONF_COLOR_BACK  // スレ一覧の背景色
 #define CONF_COLOR_BACK_BOARD_EVEN CONF_COLOR_BACK_BOARD  // スレ一覧の背景色(偶数行)
 
+#define CONF_WRITE_NAME ""  // デフォルトの書き込み名
+#define CONF_WRITE_MAIL "sage"  // デフォルトのメールアドレス
+
 // migemo-dictの場所
 #ifdef MIGEMODICT
 #define CONF_MIGEMO_PATH MIGEMODICT
