@@ -76,12 +76,12 @@ void CONFIG::set_manage_winpos( const bool manage ){ get_confitem()->manage_winp
 
 
 // 色
-const std::string& CONFIG::get_color( int id )
+const std::string& CONFIG::get_color( const int id )
 {
     return get_confitem()->str_color[ id ];
 }
 
-void CONFIG::set_color( int id, const std::string& color )
+void CONFIG::set_color( const int id, const std::string& color )
 {
     get_confitem()->str_color[ id ] = color;
 }
@@ -89,18 +89,38 @@ void CONFIG::set_color( int id, const std::string& color )
 void CONFIG::reset_colors(){ get_confitem()->reset_colors(); }
 
 const bool CONFIG::get_use_tree_gtkrc(){ return get_confitem()->use_tree_gtkrc; }
+void CONFIG::set_use_tree_gtkrc( const bool use ){ get_confitem()->use_tree_gtkrc = use; }
 
+const bool CONFIG::get_use_select_gtkrc(){ return get_confitem()->use_select_gtkrc; }
+void CONFIG::set_use_select_gtkrc( const bool use ){ get_confitem()->use_select_gtkrc = use; }
+
+// ツリービューの行間スペース
 const int CONFIG::get_tree_ypad(){ return get_confitem()->tree_ypad; }
 
+// ツリービューにエクスパンダを表示
+const bool CONFIG::get_tree_show_expanders(){ return get_confitem()->tree_show_expanders; }
+
+// ツリービューのレベルインデント調整量(ピクセル)
+const int CONFIG::get_tree_level_indent(){ return get_confitem()->tree_level_indent; }
+
+// カテゴリを開いたときにツリービューをスクロールする
+const bool CONFIG::get_scroll_tree(){ return get_confitem()->scroll_tree; }
+
 const int CONFIG::get_view_margin(){ return get_confitem()->view_margin; }
 
+// スクロールバーを左に配置
+const bool CONFIG::get_left_scrbar(){ return get_confitem()->left_scrbar; }
+
+// スレ一覧で古いスレも表示 	 
+const bool CONFIG::get_show_oldarticle(){ return get_confitem()->show_oldarticle; }
+
 // フォント
-const std::string& CONFIG::get_fontname( int id )
+const std::string& CONFIG::get_fontname( const int id )
 {
     return get_confitem()->fontname[ id ];
 }
 
-void CONFIG::set_fontname( int id, const std::string& fontname )
+void CONFIG::set_fontname( const int id, const std::string& fontname )
 {
     get_confitem()->fontname[ id ] = fontname;
 }
@@ -113,9 +133,15 @@ const int CONFIG::ref_prefix_space(){ return get_confitem()->ref_prefix_space; }
 
 const std::string& CONFIG::get_url_jdhp() { return get_confitem()->url_jdhp; }
 
+// 2chの認証サーバのアドレス
 const std::string& CONFIG::get_url_login2ch() { return get_confitem()->url_login2ch; }
+
+// p2の認証サーバのアドレス
 const std::string& CONFIG::get_url_loginp2() { return get_confitem()->url_loginp2; }
 
+// BEの認証サーバのアドレス
+const std::string& CONFIG::get_url_loginbe() { return get_confitem()->url_loginbe; }
+
 const std::string& CONFIG::get_url_bbsmenu() { return get_confitem()->url_bbsmenu; }
 
 const bool CONFIG::use_link_as_board(){ return get_confitem()->use_link_as_board; }
@@ -167,19 +193,31 @@ void CONFIG::set_proxy_for_data( const std::string& proxy ){ get_confitem()->set
 void CONFIG::set_proxy_port_for_data( int port ){ get_confitem()->proxy_port_for_data = port; }
 
 const int CONFIG::get_loader_bufsize(){ return get_confitem()->loader_bufsize; }
+const int CONFIG::get_loader_bufsize_board(){ return get_confitem()->loader_bufsize_board; }
+
 const int CONFIG::get_loader_timeout(){ return get_confitem()->loader_timeout; }
 const int CONFIG::get_loader_timeout_post(){ return get_confitem()->loader_timeout_post; }
 const int CONFIG::get_loader_timeout_data(){ return get_confitem()->loader_timeout_img; } // 旧 get_loader_timeout_img() 関数
 const int CONFIG::get_loader_timeout_checkupdate(){ return get_confitem()->loader_timeout_checkupdate; }
 
 const bool CONFIG::get_use_ipv6(){ return get_confitem()->use_ipv6; }
-void CONFIG::set_use_ipv6( bool set ){ get_confitem()->use_ipv6 = set; }
+void CONFIG::set_use_ipv6( const bool set ){ get_confitem()->use_ipv6 = set; }
+
+// 同一ホストに対する最大コネクション数( 1 または 2 )
+const int CONFIG::get_connection_num(){ return get_confitem()->connection_num; }
+
+// 2chのクッキー:HAP
+const bool CONFIG::get_use_cookie_hap(){ return get_confitem()->use_cookie_hap; }
+const std::string& CONFIG::get_cookie_hap(){ return get_confitem()->cookie_hap; }
+const std::string& CONFIG::get_cookie_hap_bbspink(){ return get_confitem()->cookie_hap_bbspink; }
+void CONFIG::set_cookie_hap( const std::string& cookie_hap ){ get_confitem()->cookie_hap = cookie_hap; }
+void CONFIG::set_cookie_hap_bbspink( const std::string& cookie_hap ){ get_confitem()->cookie_hap_bbspink = cookie_hap; }
 
 const std::string& CONFIG::get_command_openurl() { return get_confitem()->command_openurl; }
 void CONFIG::set_command_openurl( const std::string& command ){ get_confitem()->command_openurl = command; }
 
 const int CONFIG::get_browsercombo_id(){ return get_confitem()->browsercombo_id; }
-void CONFIG::set_browsercombo_id( int id ){ get_confitem()->browsercombo_id = id; }
+void CONFIG::set_browsercombo_id( const int id ){ get_confitem()->browsercombo_id = id; }
 
 const bool CONFIG::get_refpopup_by_mo(){ return get_confitem()->refpopup_by_mo; }
 const bool CONFIG::get_namepopup_by_mo(){ return get_confitem()->namepopup_by_mo; }
@@ -204,6 +242,17 @@ void CONFIG::set_use_inline_image( const bool inline_img ){ get_confitem()->use_
 const bool CONFIG::get_show_ssspicon(){ return get_confitem()->show_ssspicon; }
 void CONFIG::set_show_sssp_icon( const bool show ){ get_confitem()->show_ssspicon = show; }
 
+// インライン画像の最大幅と高さ
+const int CONFIG::get_embimg_width(){ return get_confitem()->embimg_width; }
+const int CONFIG::get_embimg_height(){ return get_confitem()->embimg_height; }
+
+// 埋め込み画像ビューを閉じたときにタブも閉じる
+const bool CONFIG::get_hide_imagetab(){ return get_confitem()->hide_imagetab; }
+
+// 画像ビューでdeleteを押したときに確認ダイアログを表示する
+const bool CONFIG::get_show_delimgdiag(){ return get_confitem()->show_delimgdiag; }
+void CONFIG::set_show_delimgdiag( const bool show ){ get_confitem()->show_delimgdiag = show; }
+
 const bool CONFIG::get_use_mosaic(){ return get_confitem()->use_mosaic; }
 void CONFIG::set_use_mosaic( const bool mosaic ) { get_confitem()->use_mosaic = mosaic; }
 const int CONFIG::get_mosaic_size(){ return get_confitem()->mosaic_size; }
@@ -215,9 +264,7 @@ const int CONFIG::get_del_imgabone_day(){ return get_confitem()->del_imgabone_da
 void CONFIG::set_del_imgabone_day( const int day ){ get_confitem()->del_imgabone_day = day; }
 const int CONFIG::get_max_img_size(){ return get_confitem()->max_img_size; }
 const int CONFIG::get_max_img_pixel(){ return get_confitem()->max_img_pixel; }
-
-const bool CONFIG::get_show_oldarticle(){ return get_confitem()->show_oldarticle; }
-void CONFIG::set_show_oldarticle( bool showarticle ){ get_confitem()->show_oldarticle = showarticle; }
+const int CONFIG::get_imgcache_size(){ return get_confitem()->imgcache_size; }
 
 const int CONFIG::get_newthread_hour(){ return get_confitem()->newthread_hour; }
 
@@ -226,15 +273,21 @@ const bool CONFIG::get_inc_search_board(){ return get_confitem()->inc_search_boa
 const bool CONFIG::get_show_deldiag(){ return get_confitem()->show_deldiag; }
 void CONFIG::set_show_deldiag( const bool show ){ get_confitem()->show_deldiag = show; }
 
+// スレ一覧をロードする前にキャッシュにある一覧を表示
+const bool CONFIG::get_show_cached_board(){ return get_confitem()->show_cached_board; }
+
+// スレ一覧でお知らせスレ(924)のアイコンを表示する
+const bool CONFIG::get_show_924(){ return get_confitem()->show_924; }
+
 const int CONFIG::get_tree_scroll_size(){ return get_confitem()->tree_scroll_size; }
 const int CONFIG::get_scroll_size(){ return get_confitem()->scroll_size; }
 const int CONFIG::get_key_scroll_size(){ return get_confitem()->key_scroll_size; }
 const int CONFIG::get_key_fastscroll_size(){ return get_confitem()->key_fastscroll_size; }
 
 const bool CONFIG::get_jump_after_reload(){ return get_confitem()->jump_after_reload; }
-void CONFIG::set_jump_after_reload( bool set ){ get_confitem()->jump_after_reload = set; }
+void CONFIG::set_jump_after_reload( const bool set ){ get_confitem()->jump_after_reload = set; }
 const bool CONFIG::get_jump_new_after_reload(){ return get_confitem()->jump_new_after_reload; }
-void CONFIG::set_jump_new_after_reload( bool set ){ get_confitem()->jump_new_after_reload = set; }
+void CONFIG::set_jump_new_after_reload( const bool set ){ get_confitem()->jump_new_after_reload = set; }
 
 const int CONFIG::get_live_mode(){ return get_confitem()->live_mode; }
 void CONFIG::set_live_mode( const int mode ) { get_confitem()->live_mode = mode; }
@@ -245,28 +298,62 @@ void CONFIG::set_live_threshode( const int th ){ get_confitem()->live_threshold
 
 const bool CONFIG::get_open_one_category(){ return get_confitem()->open_one_category; }
 const bool CONFIG::get_open_one_favorite(){ return get_confitem()->open_one_favorite; }
+
+// デフォルトの書き込み名
+const std::string CONFIG::get_write_name(){ return get_confitem()->write_name; }
+
+// デフォルトのメールアドレス
+const std::string CONFIG::get_write_mail(){ return get_confitem()->write_mail; }
+
 const bool CONFIG::get_always_write_ok() { return get_confitem()->always_write_ok; }
-void CONFIG::set_always_write_ok( bool write_ok ){ get_confitem()->always_write_ok = write_ok; }
+void CONFIG::set_always_write_ok( const bool write_ok ){ get_confitem()->always_write_ok = write_ok; }
 
 const bool CONFIG::get_save_post_log(){ return get_confitem()->save_postlog; }
-void CONFIG::set_save_post_log( bool save ){ get_confitem()->save_postlog = save; }
+void CONFIG::set_save_post_log( const bool save ){ get_confitem()->save_postlog = save; }
 const size_t CONFIG::get_maxsize_post_log(){ return get_confitem()->maxsize_postlog; }
 
 // 書き込み履歴を保存
 const bool CONFIG::get_save_post_history(){ return get_confitem()->save_posthist; }
-void CONFIG::set_save_post_history( bool save ){ get_confitem()->save_posthist = save; }
+void CONFIG::set_save_post_history( const bool save ){ get_confitem()->save_posthist = save; }
 
 const bool CONFIG::get_hide_writing_dialog(){ return get_confitem()->hide_writing_dialog; }
+
+// 編集中のメッセージの保存確認ダイアログを表示する
+const bool CONFIG::get_show_savemsgdiag(){ return get_confitem()->show_savemsgdiag; }
+void CONFIG::set_show_savemsgdiag( const bool show ){ get_confitem()->show_savemsgdiag = show; }
+
+// 書き込みビューでテキストを折り返す
+const bool CONFIG::get_message_wrap(){ return get_confitem()->message_wrap; }
+void CONFIG::set_message_wrap( const bool wrap ){ get_confitem()->message_wrap = wrap; }
+
 const bool CONFIG::get_fold_message(){ return get_confitem()->fold_message; }
-void CONFIG::set_fold_message( bool fold ){ get_confitem()->fold_message = fold; }
+void CONFIG::set_fold_message( const bool fold ){ get_confitem()->fold_message = fold; }
+
+const bool CONFIG::get_fold_image(){ return get_confitem()->fold_image; }
+
+const bool CONFIG::get_keep_im_status(){ return get_confitem()->keep_im_status; }
 
 const int CONFIG::get_margin_popup(){ return get_confitem()->margin_popup; }
-void CONFIG::set_margin_popup( int margin ){ get_confitem()->margin_popup = margin; }
+void CONFIG::set_margin_popup( const int margin ){ get_confitem()->margin_popup = margin; }
 
+// 画像ポップアップとカーソルの間のマージン
+const int CONFIG::get_margin_imgpopup_x(){ return get_confitem()->margin_imgpopup_x; }
 const int CONFIG::get_margin_imgpopup(){ return get_confitem()->margin_imgpopup; }
 
+// ポップアップが消えるまでの時間(ミリ秒)
+const int CONFIG::get_hide_popup_msec(){ return get_confitem()->hide_popup_msec; }
+
+// マウスジェスチャを有効
+const bool CONFIG::get_enable_mg(){ return get_confitem()->enable_mg; }
+
+// マウスジェスチャの判定開始半径
 const int CONFIG::get_mouse_radius(){ return get_confitem()->mouse_radius; }
+
+// 数字入力ジャンプのウェイト(ミリ秒)
+const int CONFIG::get_numberjmp_msec(){ return get_confitem()->numberjmp_msec; }
+
 const int CONFIG::get_history_size(){ return get_confitem()->history_size; }
+const int CONFIG::get_historyview_size(){ return get_confitem()->historyview_size; }
 const int CONFIG::get_aahistory_size(){ return get_confitem()->aahistory_size; }
 
 // 0以上なら多重ポップアップの説明を表示する
@@ -284,7 +371,7 @@ const bool CONFIG::get_instruct_tglart(){
     get_confitem()->instruct_tglart_end = true; // 一度表示したら表示しない
     return get_confitem()->instruct_tglart;
 }
-void CONFIG::set_instruct_tglart( bool tgl ){ get_confitem()->instruct_tglart = tgl; }
+void CONFIG::set_instruct_tglart( const bool tgl ){ get_confitem()->instruct_tglart = tgl; }
 
 const bool CONFIG::get_instruct_tglimg(){
 
@@ -297,16 +384,21 @@ const bool CONFIG::get_instruct_tglimg(){
 void CONFIG::set_instruct_tglimg( bool tgl ){ get_confitem()->instruct_tglimg = tgl; }
 
 
+// スレビューでdeleteを押したときに確認ダイアログを表示する
+const bool CONFIG::get_show_delartdiag(){ return get_confitem()->show_delartdiag; }
+void CONFIG::set_show_delartdiag( const bool show ){ get_confitem()->show_delartdiag = show; }
+
+
 const double CONFIG::get_adjust_underline_pos(){ return get_confitem()->adjust_underline_pos; }
-void CONFIG::set_adjust_underline_pos( double pos ){ get_confitem()->adjust_underline_pos = pos; }
+void CONFIG::set_adjust_underline_pos( const double pos ){ get_confitem()->adjust_underline_pos = pos; }
 
 const double CONFIG::get_adjust_line_space(){ return get_confitem()->adjust_line_space; }
-void CONFIG::set_adjust_line_space( double space ){ get_confitem()->adjust_line_space = space; }
+void CONFIG::set_adjust_line_space( const double space ){ get_confitem()->adjust_line_space = space; }
 
 const bool CONFIG::get_draw_underline(){ return get_confitem()->draw_underline; }
 
 const bool CONFIG::get_strict_char_width(){ return get_confitem()->strict_char_width; }
-void CONFIG::set_strict_char_width( bool strictwidth ){ get_confitem()->strict_char_width = strictwidth; }
+void CONFIG::set_strict_char_width( const bool strictwidth ){ get_confitem()->strict_char_width = strictwidth; }
 
 const bool CONFIG::get_check_id(){ return get_confitem()->check_id; }
 
@@ -318,19 +410,27 @@ const int CONFIG::get_num_id_low(){ return get_confitem()->num_id_low; }
 const bool CONFIG::get_loose_url(){ return get_confitem()->loose_url; }
 
 const bool CONFIG::get_hide_usrcmd(){ return get_confitem()->hide_usrcmd; }
-void CONFIG::set_hide_usrcmd( bool hide ){ get_confitem()->hide_usrcmd = hide; }
+void CONFIG::set_hide_usrcmd( const bool hide ){ get_confitem()->hide_usrcmd = hide; }
 
 const bool CONFIG::get_reload_allthreads(){ return get_confitem()->reload_allthreads; }
 
 const int CONFIG::get_tab_min_str(){ return get_confitem()->tab_min_str; }
 
 const bool CONFIG::get_show_tab_icon(){ return get_confitem()->show_tab_icon; }
+
+// タブ上でマウスホイールを回転してタブを切り替える
+const bool CONFIG::get_switchtab_wheel(){ return get_confitem()->switchtab_wheel; }
+
 const bool CONFIG::get_show_post_mark(){ return get_confitem()->show_post_mark; }
 void CONFIG::set_show_post_mark( const bool show ){ get_confitem()->show_post_mark = show; }
 
 const bool CONFIG::get_flat_button(){ return get_confitem()->flat_button; }
 void CONFIG::set_flat_button( const bool set ){ get_confitem()->flat_button = set; }
 
+// ツールバーの背景描画
+const bool CONFIG::get_draw_toolbarback(){ return get_confitem()->draw_toolbarback; }
+void CONFIG::set_draw_toolbarback( const bool set ){ get_confitem()->draw_toolbarback = set; }
+
 std::list< std::string >& CONFIG::get_list_abone_word_thread(){ return get_confitem()->list_abone_word_thread; }
 std::list< std::string >& CONFIG::get_list_abone_regex_thread(){ return get_confitem()->list_abone_regex_thread; }
 
@@ -351,6 +451,9 @@ void CONFIG::set_list_abone_regex_thread( std::list< std::string >& regex )
 }
 
 
+const int CONFIG::get_remove_old_abone_thread(){ return get_confitem()->remove_old_abone_thread; } 
+void CONFIG::set_remove_old_abone_thread( const int remove ){ get_confitem()->remove_old_abone_thread = remove; }
+
 const int CONFIG::get_abone_number_thread(){ return get_confitem()->abone_number_thread; } 
 void CONFIG::set_abone_number_thread( const int number ){ get_confitem()->abone_number_thread = number; }
 
@@ -384,21 +487,39 @@ void CONFIG::set_list_abone_regex( const std::list< std::string >& regex )
     get_confitem()->list_abone_regex = MISC::remove_nullline_from_list( get_confitem()->list_abone_regex );
 }
 
+
+// デフォルトで透明、連鎖あぼーんをするか
 const bool CONFIG::get_abone_transparent(){ return get_confitem()->abone_transparent; }
 void CONFIG::set_abone_transparent( const bool set ){ get_confitem()->abone_transparent = set; }
+
 const bool CONFIG::get_abone_chain(){ return get_confitem()->abone_chain; }
 void CONFIG::set_abone_chain( const bool set ){ get_confitem()->abone_chain = set; }
 
+// NG正規表現によるあぼーん時に大小と全半角文字の違いを無視
+const bool CONFIG::get_abone_icase(){ return get_confitem()->abone_icase; }
+void CONFIG::set_abone_icase( const bool set ){ get_confitem()->abone_icase = set; }
+
+const bool CONFIG::get_abone_wchar(){ return get_confitem()->abone_wchar; }
+void CONFIG::set_abone_wchar( const bool set ){ get_confitem()->abone_wchar = set; }
+
+
 const bool CONFIG::get_expand_sidebar(){ return get_confitem()->expand_sidebar; }
 
 const bool CONFIG::get_expand_rpane(){ return get_confitem()->expand_rpane; }
 
+// ペーンの境界をクリックしてサイドバーを開け閉めする
+const bool CONFIG::get_open_sidebar_by_click(){ return get_confitem()->open_sidebar_by_click; }
 
 // 次スレ検索の類似度のしきい値
 const int CONFIG::get_threshold_next(){ return get_confitem()->threshold_next; }
 
 // 次スレを開いたときにお気に入りのアドレスと名前を自動更新
-const bool CONFIG::get_replace_favorite_next(){ return get_confitem()->replace_favorite_next; }
+const int CONFIG::get_replace_favorite_next(){ return get_confitem()->replace_favorite_next; }
+void CONFIG::set_replace_favorite_next( const int mode ){ get_confitem()->replace_favorite_next = mode; }
+
+// お気に入りの自動更新をするかダイアログを出す
+const bool CONFIG::show_diag_replace_favorite(){ return get_confitem()->show_diag_replace_favorite; }
+void CONFIG::set_show_diag_replace_favorite( const bool show ){ get_confitem()->show_diag_replace_favorite = show; }
 
 // スレをお気に入りに追加したときにしおりをセットする
 const bool CONFIG::get_bookmark_drop(){ return get_confitem()->bookmark_drop; }
@@ -406,13 +527,45 @@ const bool CONFIG::get_bookmark_drop(){ return get_confitem()->bookmark_drop; }
 // お気に入りの更新チェック時に板の更新もチェックする
 const bool CONFIG::get_check_update_board(){ return get_confitem()->check_update_board; }
 
+// 起動時にお気に入りを自動でチェックする
+const bool CONFIG::get_check_update_boot(){ return get_confitem()->check_update_boot; }
+
+// お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示 2: 登録しない )
+const int CONFIG::get_check_favorite_dup(){ return get_confitem()->check_favorite_dup; }
+void CONFIG::set_check_favorite_dup( const int check ){ get_confitem()->check_favorite_dup = check; }
+
+// お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
+const int CONFIG::get_show_favorite_select_diag(){ return get_confitem()->show_favorite_select_diag; }
+
 // Ctrl+qでウィンドウを閉じない
 const bool CONFIG::get_disable_close(){ return get_confitem()->disable_close; }
 
+// メニューバーを非表示にした時にダイアログを表示
+const bool CONFIG::get_show_hide_menubar_diag(){ return get_confitem()->show_hide_menubar_diag; }
+void CONFIG::set_show_hide_menubar_diag( const bool set ){ get_confitem()->show_hide_menubar_diag = set; }
+
+// 状態変更時にメインステータスバーの色を変える
+const bool CONFIG::get_change_stastatus_color(){ return get_confitem()->change_stastatus_color; }
+
 // まちBBSの取得に offlaw.cgi を使用する
 const bool CONFIG::get_use_machi_offlaw(){ return get_confitem()->use_machi_offlaw; }
 void CONFIG::set_use_machi_offlaw( const bool set ){ get_confitem()->use_machi_offlaw = set; }
 
+// 書き込み履歴のあるスレを削除する時にダイアログを表示
+const bool CONFIG::get_show_del_written_thread_diag(){ return get_confitem()->show_del_written_thread_diag; }
+void CONFIG::set_del_written_thread_diag( const bool set ){ get_confitem()->show_del_written_thread_diag = set; }
+
+// スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+const int CONFIG::get_delete_img_in_thread(){ return get_confitem()->delete_img_in_thread; }
+void CONFIG::set_delete_img_in_thread( const int set ){ get_confitem()->delete_img_in_thread = set; }
+
+// FIFOの作成などにエラーがあったらダイアログを表示する
+const bool CONFIG::get_show_diag_fifo_error(){ return get_confitem()->show_diag_fifo_error; }
+void CONFIG::set_show_diag_fifo_error( const bool set ){ get_confitem()->show_diag_fifo_error = set; }
+
+// 指定した分ごとにセッションを自動保存 (0: 保存しない)
+const int CONFIG::get_save_session(){ return get_confitem()->save_session; }
+
 
 #ifdef HAVE_MIGEMO_H
 const std::string& CONFIG::get_migemodict_path() { return get_confitem()->migemodict_path; }
