@@ -55,12 +55,24 @@ namespace CONFIG
     // ツリービューの行間スペース
     const int get_tree_ypad();
 
+    // ツリービューにエクスパンダを表示
+    const bool get_tree_show_expanders();
+
+    // ツリービューのレベルインデント調整量(ピクセル)
+    const int get_tree_level_indent();
+
     // カテゴリを開いたときにツリービューをスクロールする
     const bool get_scroll_tree();
 
     // 各ビューと枠との間の余白
     const int get_view_margin();
 
+    // スクロールバーを左に配置
+    const bool get_left_scrbar();
+
+    // スレ一覧で古いスレも表示 	 
+    const bool get_show_oldarticle();
+
     // フォント
     const std::string& get_fontname( const int id );
     void set_fontname( const int id, const std::string& fontname );
@@ -81,6 +93,9 @@ namespace CONFIG
     // p2の認証サーバのアドレス
     const std::string& get_url_loginp2();
 
+    // BEの認証サーバのアドレス
+    const std::string& get_url_loginbe();
+
     // bbsmenu.htmlのURL
     const std::string& get_url_bbsmenu();    
 
@@ -159,6 +174,16 @@ namespace CONFIG
     const bool get_use_ipv6();
     void set_use_ipv6( const bool set );
 
+    // 同一ホストに対する最大コネクション数( 1 または 2 )
+    const int get_connection_num();
+
+    // 2chのクッキー:HAP
+    const bool get_use_cookie_hap();
+    const std::string& get_cookie_hap();
+    const std::string& get_cookie_hap_bbspink();
+    void set_cookie_hap( const std::string& cookie_hap );
+    void set_cookie_hap_bbspink( const std::string& cookie_hap );
+
     // リンクをクリックしたときに実行するコマンド
     const std::string& get_command_openurl();
     void set_command_openurl( const std::string& command );
@@ -201,6 +226,17 @@ namespace CONFIG
     const bool get_show_ssspicon();
     void set_show_sssp_icon( const bool show );
 
+    // インライン画像の最大幅と高さ
+    const int get_embimg_width();
+    const int get_embimg_height();
+
+    // 埋め込み画像ビューを閉じたときにタブも閉じる
+    const bool get_hide_imagetab();
+
+    // 画像ビューでdeleteを押したときに確認ダイアログを表示する
+    const bool get_show_delimgdiag();
+    void set_show_delimgdiag( const bool show );
+
     // 画像にモザイクかける
     const bool get_use_mosaic();
     void set_use_mosaic( const bool mosaic );
@@ -229,10 +265,6 @@ namespace CONFIG
     // 画像のメモリキャッシュ枚数
     const int get_imgcache_size();
 
-    // スレ一覧にdat落ちしたスレも表示する
-    const bool get_show_oldarticle();
-    void set_show_oldarticle( const bool showarticle );
-
     // スレ一覧で指定した値(時間)よりも後に立てられたスレを新着とみなす
     const int get_newthread_hour();
 
@@ -287,6 +319,12 @@ namespace CONFIG
     // お気に入りでカテゴリを常にひとつだけ開く
     const bool get_open_one_favorite();
 
+    // デフォルトの書き込み名
+    const std::string get_write_name();
+
+    // デフォルトのメールアドレス
+    const std::string get_write_mail();
+
     // 書き込み時に書き込み確認ダイアログを出すかどうか
     const bool get_always_write_ok();
     void set_always_write_ok( const bool write_ok );
@@ -305,10 +343,21 @@ namespace CONFIG
     // 書き込み中のダイアログを表示しない
     const bool get_hide_writing_dialog();
 
+    // 編集中のメッセージの保存確認ダイアログを表示する
+    const bool get_show_savemsgdiag();
+    void set_show_savemsgdiag( const bool show );
+
+    // 書き込みビューでテキストを折り返す
+    const bool get_message_wrap();
+    void set_message_wrap( const bool wrap );
+
     // 非アクティブ時に書き込みビューを折りたたむ
     const bool get_fold_message();
     void set_fold_message( const bool fold );
 
+    // 非アクティブ時に画像ビューを折りたたむ
+    const bool get_fold_image();
+
     // 書き込み欄の日本語のON/OFF状態を保存
     const bool get_keep_im_status();
 
@@ -317,11 +366,21 @@ namespace CONFIG
     void set_margin_popup( const int margin );
 
     // 画像ポップアップとカーソルの間のマージン
-    const int get_margin_imgpopup();
+    const int get_margin_imgpopup_x(); // 水平方向
+    const int get_margin_imgpopup(); // 垂直方向
+
+    // ポップアップが消えるまでの時間(ミリ秒)
+    const int get_hide_popup_msec();
+
+    // マウスジェスチャを有効
+    const bool get_enable_mg();
 
     // マウスジェスチャの判定開始半径
     const int get_mouse_radius();
 
+    // 数字入力ジャンプの待ち時間(ミリ秒)
+    const int get_numberjmp_msec();
+
     // 履歴メニューの表示数
     const int get_history_size();
 
@@ -342,6 +401,10 @@ namespace CONFIG
     const bool get_instruct_tglimg();
     void set_instruct_tglimg( const bool set );
 
+    // スレビューでdeleteを押したときに確認ダイアログを表示する
+    const bool get_show_delartdiag();
+    void set_show_delartdiag( const bool show );
+
     // 下線位置調整
     const double get_adjust_underline_pos();
     void set_adjust_underline_pos( const double pos );
@@ -384,6 +447,9 @@ namespace CONFIG
     // タブにアイコンを表示するか
     const bool get_show_tab_icon();
 
+    // タブ上でマウスホイールを回転してタブを切り替える
+    const bool get_switchtab_wheel();
+
     // スレビューに書き込みマークを表示するか
     const bool get_show_post_mark();
     void set_show_post_mark( const bool show );
@@ -428,12 +494,22 @@ namespace CONFIG
     const bool get_abone_chain();
     void set_abone_chain( const bool set );
 
+    // NG正規表現によるあぼーん時に大小と全半角文字の違いを無視
+    const bool get_abone_icase();
+    void set_abone_icase( const bool set );
+
+    const bool get_abone_wchar();
+    void set_abone_wchar( const bool set );
+
     // 右ペーンが空の時にサイドバーを閉じるか
     const bool get_expand_sidebar();
 
     // 3ペーン時にスレ一覧やスレビューを最大化するか
     const bool get_expand_rpane();
 
+    // ペーンの境界をクリックしてサイドバーを開け閉めする
+    const bool get_open_sidebar_by_click();
+
     // 次スレ検索の類似度のしきい値
     const int get_threshold_next();
 
@@ -454,9 +530,23 @@ namespace CONFIG
     // 起動時にお気に入りを自動でチェックする
     const bool get_check_update_boot();
 
+    // お気に入り登録時に重複項目を登録するか ( 0: 登録する 1: ダイアログ表示  2: 登録しない )
+    const int get_check_favorite_dup();
+    void set_check_favorite_dup( const int check );
+
+    // お気に入り登録時に挿入先ダイアログを表示する ( 0 : 表示する 1: 表示せず先頭に追加 2: 表示せず最後に追加 )
+    const int get_show_favorite_select_diag();
+
     // Ctrl+qでウィンドウを閉じない
     const bool get_disable_close();
 
+    // メニューバーを非表示にした時にダイアログを表示
+    const bool get_show_hide_menubar_diag();
+    void set_show_hide_menubar_diag( const bool set );
+
+    // 状態変更時にメインステータスバーの色を変える
+    const bool get_change_stastatus_color();
+
     // まちBBSの取得に offlaw.cgi を使用する
     const bool get_use_machi_offlaw();
     void set_use_machi_offlaw( const bool set );
@@ -465,10 +555,17 @@ namespace CONFIG
     const bool get_show_del_written_thread_diag();
     void set_del_written_thread_diag( const bool set );
 
+    // スレを削除する時に画像キャッシュも削除する ( 0: ダイアログ表示 1: 削除 2: 削除しない )
+    const int get_delete_img_in_thread();
+    void set_delete_img_in_thread( const int set );
+
     // FIFOの作成などにエラーがあったらダイアログを表示する
     const bool get_show_diag_fifo_error();
     void set_show_diag_fifo_error( const bool set );
 
+    // 指定した分ごとにセッションを自動保存 (0: 保存しない)
+    const int get_save_session();
+
 #ifdef HAVE_MIGEMO_H
     // migemo-dictの場所
     const std::string& get_migemodict_path();
