@@ -106,6 +106,9 @@ namespace CORE
         // 初期設定中
         bool m_init;
 
+        // セッション保存までのカウンタ
+        int m_count_savesession;
+
     public:
 
         Core( JDWinMain& win_main );
@@ -119,8 +122,8 @@ namespace CORE
 
         void set_command( const COMMAND_ARGS& command );
 
-        // SIGHUPを受け取った時の処理
-        void shutdown();
+        // セッション保存
+        void save_session();
 
     private:
 
@@ -150,6 +153,8 @@ namespace CORE
         void slot_clear_board();
         void slot_clear_thread();
         void slot_clear_close();
+        void slot_clear_closeboard();
+        void slot_clear_closeimg();
         void slot_clear_search();
         void slot_clear_name();
         void slot_clear_mail();
@@ -157,6 +162,7 @@ namespace CORE
         bool open_color_diag( std::string title, int id );
         
         void toggle_menubar();
+        void toggle_statbar();
         void toggle_flat_button();
         void toggle_draw_toolbarback();
         void toggle_post_mark();
@@ -217,6 +223,9 @@ namespace CORE
         // 板にdatファイルをインポートする
         void import_dat( const std::string& url_board, const std::list< std::string > list_files );
 
+        // サイドバー更新チェック
+        // open : 更新があったらタブで開く
+        void check_update( const bool open );
 
         //
         // メニュー関係( menuslots.cpp の中に記述)
@@ -227,11 +236,11 @@ namespace CORE
         void slot_toggle_loginbe();
         void slot_toggle_loginp2();
         void slot_reload_list();
-        void slot_save_favorite();
         void slot_quit();
         ///
         void slot_toggle_since( const int mode );
         void slot_toggle_write( const int mode );
+        void slot_toggle_toolbarmain();
         void slot_toggle_toolbarpos( const int pos );
         void slot_toggle_toolbarbbslist();
         void slot_toggle_toolbarboard();
@@ -241,8 +250,10 @@ namespace CORE
         void slot_toggle_2pane();
         void slot_toggle_3pane();
         void slot_toggle_v3pane();
+        void slot_toggle_fullscreen();
         void slot_toggle_winmsg();
         void slot_toggle_embmsg();
+        void slot_toggle_msg_wrap();
         void slot_toggle_imgview( const int mode );
         void slot_toggle_use_imgpopup();
         void slot_toggle_use_inlineimg();
@@ -252,14 +263,15 @@ namespace CORE
         void slot_setup_sidebaritem();
         void slot_setup_boarditem();
         void slot_setup_articleitem();
+        void slot_setup_searchitem();
         void slot_setup_msgitem();
         void slot_setup_boarditem_menu();
         void slot_setup_articleitem_menu();
         //
+        void slot_bbslist_pref();
         void slot_board_pref();
         void slot_article_pref();
         void slot_image_pref();
-        void slot_toggle_oldarticle();
         void slot_toggle_restore_views();
         void slot_toggle_fold_message();
         void slot_toggle_save_post_log();
@@ -288,6 +300,7 @@ namespace CORE
         void slot_setup_abone();
         void slot_setup_abone_thread();
         void slot_toggle_abone_transp_chain();
+        void slot_toggle_abone_icase_wchar();
         void slot_setup_live();
         void slot_usrcmd_pref();
         void slot_filter_pref();
