@@ -17,14 +17,18 @@
 #include "jdlib/miscutil.h"
 #include "jdlib/miscgtk.h"
 
+#include "control/controlutil.h"
+#include "control/controlid.h"
+
+#include "config/globalconf.h"
+
 #include "cache.h"
 #include "command.h"
 #include "sharedbuffer.h"
 #include "global.h"
 #include "type.h"
-#include "controlutil.h"
-#include "controlid.h"
 #include "prefdiagfactory.h"
+#include "usrcmdmanager.h"
 #include "httpcode.h"
 #include "session.h"
 
@@ -40,6 +44,7 @@ using namespace IMAGE;
 
 ImageViewBase::ImageViewBase( const std::string& url, const std::string& arg1, const std::string& arg2 )
     : SKELETON::View( url ),
+      m_wait( false ),
       m_loading( false ),
       m_under_mouse( false ),
       m_enable_menuslot( true )
@@ -68,6 +73,15 @@ SKELETON::Admin* ImageViewBase::get_admin()
 }
 
 
+//
+// 親ウィンドウを取得
+//
+Gtk::Window* ImageViewBase::get_parent_win()
+{
+    return IMAGE::get_admin()->get_win();
+}
+
+
 //
 // 共通セットアップ
 //
@@ -102,7 +116,7 @@ void ImageViewBase::setup_common()
                          sigc::mem_fun( *this, &ImageViewBase::slot_show_large_img ) );
     action_group()->add( Gtk::Action::create( "LoadStop", "StopLoading" ), sigc::mem_fun( *this, &ImageViewBase::stop ) );
     action_group()->add( Gtk::Action::create( "Reload", "強制再読み込み(_E)"), sigc::mem_fun( *this, &ImageViewBase::slot_reload_force ) );
-    action_group()->add( Gtk::Action::create( "AppendFavorite", "お気に入りに追加(_F)..."), sigc::mem_fun( *this, &ImageViewBase::slot_favorite ) );
+    action_group()->add( Gtk::Action::create( "AppendFavorite", "AppendFavorite"), sigc::mem_fun( *this, &ImageViewBase::slot_favorite ) );
 
     action_group()->add( Gtk::Action::create( "ZoomFitImage", "ZoomFitImage" ),
                          sigc::mem_fun( *this, &ImageViewBase::slot_fit_win ) );
@@ -126,7 +140,7 @@ void ImageViewBase::setup_common()
         action_group()->add( action, sigc::bind< int >( sigc::mem_fun( *this, &ImageViewBase::slot_resize_image ), tmp_size ) );
     }
 
-    action_group()->add( Gtk::Action::create( "Move_Menu", "移動(_M)" ) );
+    action_group()->add( Gtk::Action::create( "Move_Menu", ITEM_NAME_GO + std::string( "(_M)" ) ) );
     action_group()->add( Gtk::Action::create( "MoveHead", "先頭に移動(_H)" ), sigc::mem_fun( *this, &ImageViewBase::slot_move_head ) );
     action_group()->add( Gtk::Action::create( "MoveTail", "最後に移動(_T)" ), sigc::mem_fun( *this, &ImageViewBase::slot_move_tail ) );
 
@@ -136,15 +150,21 @@ void ImageViewBase::setup_common()
     action_group()->add( Gtk::Action::create( "CloseOther", "他の画像(_O)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_other_views ) );
     action_group()->add( Gtk::Action::create( "CloseLeft", "左←の画像(_L)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_left_views ) );
     action_group()->add( Gtk::Action::create( "CloseRight", "右→の画像(_R)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_right_views ) );
+    action_group()->add( Gtk::Action::create( "CloseError404", "エラー画像(404,403のみ)(_E)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_error_views ) );
+    action_group()->add( Gtk::Action::create( "CloseError503", "エラー画像(timeout,503以外)(_T)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_notimeout_error_views ) );
+    action_group()->add( Gtk::Action::create( "CloseErrorAll", "エラー画像(読込み中含め全て)(_W)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_all_error_views ) );
+    action_group()->add( Gtk::Action::create( "CloseNoError", "エラー以外の画像(_N)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_noerror_views ) );
     action_group()->add( Gtk::Action::create( "CloseAll", "全ての画像(_A)" ), sigc::mem_fun( *this, &ImageViewBase::slot_close_all_views ) );
 
     action_group()->add( Gtk::ToggleAction::create( "LockTab", "タブをロックする(_K)", std::string(), false ),
                          sigc::mem_fun( *this, &ImageViewBase::slot_lock ) );
 
-    action_group()->add( Gtk::Action::create( "OpenBrowser", "ブラウザで開く(_W)"),
+    action_group()->add( Gtk::Action::create( "OpenBrowser", ITEM_NAME_OPEN_BROWSER + std::string( "(_W)" ) ),
                          sigc::mem_fun( *this, &ImageViewBase::slot_open_browser ) );
+    action_group()->add( Gtk::Action::create( "OpenCacheBrowser", ITEM_NAME_OPEN_CACHE_BROWSER + std::string( "(_X)" ) ),
+                         sigc::mem_fun( *this, &ImageViewBase::slot_open_cache_browser ) );
     action_group()->add( Gtk::Action::create( "OpenRef", "参照元のレスを開く(_O)"), sigc::mem_fun( *this, &ImageViewBase::slot_open_ref ) );
-    action_group()->add( Gtk::Action::create( "CopyURL", "URLをコピー(_U)"), sigc::mem_fun( *this, &ImageViewBase::slot_copy_url ) );
+    action_group()->add( Gtk::Action::create( "CopyURL", ITEM_NAME_COPY_URL + std::string( "(_U)" ) ), sigc::mem_fun( *this, &ImageViewBase::slot_copy_url ) );
     action_group()->add( Gtk::Action::create( "Save", "Save"), sigc::mem_fun( *this, &ImageViewBase::slot_save ) );
     action_group()->add( Gtk::Action::create( "SaveAll", "全ての画像を保存(_A)..."), sigc::mem_fun( *this, &ImageViewBase::slot_save_all ) );
 
@@ -157,12 +177,19 @@ void ImageViewBase::setup_common()
 
     action_group()->add( Gtk::Action::create( "Preference", "プロパティ(_P)..."), sigc::mem_fun( *this, &ImageViewBase::show_preference ) );
 
+    const std::string usrcmd = CORE::get_usrcmd_manager()->create_usrcmd_menu( action_group() );
+    const int usrcmd_size = CORE::get_usrcmd_manager()->get_size();
+    for( int i = 0; i < usrcmd_size; ++i ){
+        Glib::RefPtr< Gtk::Action > act = CORE::get_usrcmd_manager()->get_action( action_group(), i );
+        if( act ) act->signal_activate().connect(
+            sigc::bind< int >( sigc::mem_fun( *this, &ImageViewBase::slot_usrcmd ), i ) );
+    }
+
     ui_manager() = Gtk::UIManager::create();    
     ui_manager()->insert_action_group( action_group() );
 
-    Glib::ustring str_ui = 
-
-    "<ui>"
+    // 画像ビューのメニュー
+    const std::string menu = 
 
     "<popup name='popup_menu'>"
 
@@ -189,7 +216,10 @@ void ImageViewBase::setup_common()
     "<separator/>"
 
     "<menuitem action='OpenBrowser'/>"
+    "<menuitem action='OpenCacheBrowser'/>"
     "<menuitem action='OpenRef'/>"
+    + usrcmd
+    + std::string( 
     "<separator/>"
 
     "<menuitem action='CopyURL'/>"
@@ -215,12 +245,11 @@ void ImageViewBase::setup_common()
 
     "<menuitem action='Preference'/>"
 
-
     "</popup>"
-
-    //////////////////////////
+    );
 
     // アイコンのメニュー
+    const std::string menu_icon = 
     
     "<popup name='popup_menu_icon'>"
 
@@ -241,6 +270,12 @@ void ImageViewBase::setup_common()
     "<menuitem action='CloseOther'/>"
     "<menuitem action='CloseLeft'/>"
     "<menuitem action='CloseRight'/>"
+    "<separator/>"
+    "<menuitem action='CloseError404'/>"
+    "<menuitem action='CloseError503'/>"
+    "<menuitem action='CloseErrorAll'/>"
+    "<separator/>"
+    "<menuitem action='CloseNoError'/>"
     "</menu>"
     "<separator/>"
 
@@ -248,6 +283,7 @@ void ImageViewBase::setup_common()
     "<separator/>"
 
     "<menuitem action='OpenBrowser'/>"
+    "<menuitem action='OpenCacheBrowser'/>"
     "<menuitem action='OpenRef'/>"
     "<separator/>"
 
@@ -274,12 +310,48 @@ void ImageViewBase::setup_common()
     "<separator/>"
     "<menuitem action='Preference'/>"
 
+    "</popup>";
+
+    // 画像ポップアップのメニュー
+    const std::string menu_popup = 
+
+    "<popup name='popup_menu_popup'>"
+
+    "<menuitem action='CancelMosaic'/>"
+    "<separator/>"
+
+    "<menuitem action='Quit'/>"
+    "<separator/>"
+
+    "<menuitem action='CopyURL'/>"
+    "<separator/>"
+
+    "<menuitem action='Save'/>"
+    "<separator/>"
+
+    "<menuitem action='ProtectImage'/>"
+    "<menu action='DeleteMenu'>"
+    "<menuitem action='DeleteImage'/>"
+    "</menu>"
+
+    "<separator/>"
+    "<menuitem action='AboneImage'/>"
+
+    "<separator/>"
+
+    "<menuitem action='Preference'/>"
+
     "</popup>"
+    ;
 
-    "</ui>";
-
-    ui_manager()->add_ui_from_string( str_ui );
 
+    ui_manager()->add_ui_from_string(
+        "<ui>"
+        + menu
+        + menu_icon
+        + menu_popup
+        + "</ui>"
+        );
 
     // ポップアップメニューにキーアクセレータやマウスジェスチャを表示
     Gtk::Menu* popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu" ) );
@@ -287,6 +359,9 @@ void ImageViewBase::setup_common()
 
     popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_icon" ) );
     CONTROL::set_menu_motion( popupmenu );
+
+    popupmenu = dynamic_cast< Gtk::Menu* >( ui_manager()->get_widget( "/popup_menu_popup" ) );
+    CONTROL::set_menu_motion( popupmenu );
 }
 
 
@@ -323,9 +398,10 @@ void ImageViewBase::remove_imagearea()
 //
 // コマンド
 //
-bool ImageViewBase::set_command( const std::string& command, const std::string& arg )
+const bool ImageViewBase::set_command( const std::string& command, const std::string& arg1, const std::string& arg2 )
 {
     if( command == "switch_icon" ) switch_icon();
+    else if( command == "update_status" ) update_status();
 
     return true;
 }
@@ -342,7 +418,14 @@ void ImageViewBase::reload()
 #endif
 
     std::string refurl = m_img->get_refurl();
-    m_img->download_img( refurl );
+    const bool mosaic = m_img->get_mosaic();
+    m_img->download_img( refurl, mosaic, 0 );
+
+    if( m_img->is_loading() ){
+
+        CORE::core_set_command( "redraw", get_url() );
+        CORE::core_set_command( "redraw_article" );
+    }
 }
 
 
@@ -432,6 +515,41 @@ void ImageViewBase::slot_close_right_views()
 }
 
 
+//
+// エラーの画像を閉じる( HTTP404 のみ )
+//
+void ImageViewBase::slot_close_error_views()
+{
+    IMAGE::get_admin()->set_command( "close_error_views", "", "" );
+}
+
+
+//
+// エラーの画像を閉じる( timeout, 503 以外 )
+//
+void ImageViewBase::slot_close_notimeout_error_views()
+{
+    IMAGE::get_admin()->set_command( "close_error_views", "", "notimeout" );
+}
+
+
+//
+// エラーの画像を閉じる( 全て )
+//
+void ImageViewBase::slot_close_all_error_views()
+{
+    IMAGE::get_admin()->set_command( "close_error_views", "", "all" );
+}
+
+
+//
+// エラー以外の画像を閉じる
+//
+void ImageViewBase::slot_close_noerror_views()
+{
+    IMAGE::get_admin()->set_command( "close_noerror_views" );
+}
+
 
 //
 // 全ての画像を閉じる
@@ -447,7 +565,9 @@ void ImageViewBase::slot_close_all_views()
 //
 void ImageViewBase::show_preference()
 {
-    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( IMAGE::get_admin()->get_win(), CORE::PREFDIAG_IMAGE, get_url() );
+    CORE::core_set_command( "hide_popup" );
+
+    SKELETON::PrefDiag* pref= CORE::PrefDiagFactory( get_parent_win(), CORE::PREFDIAG_IMAGE, get_url() );
 
     IMAGE::get_admin()->set_command_immediately( "disable_fold_win" ); // run 直前に呼ぶこと
     pref->run();
@@ -462,16 +582,59 @@ void ImageViewBase::show_preference()
 //
 void ImageViewBase::delete_view()
 {
+    delete_view_impl( false );
+}
+
+
+void ImageViewBase::delete_view_impl( const bool show_diag )
+{
+    CORE::core_set_command( "hide_popup" );
+
+    if( show_diag ){
+
+        if( m_img->is_protected() ){
+
+            SKELETON::MsgDiag mdiag( get_parent_win(), "キャッシュ保護されています" );
+            mdiag.run();
+            return;
+        }
+        else if( CONFIG::get_show_delimgdiag() ){
+
+            SKELETON::MsgCheckDiag mdiag( get_parent_win(),
+                                          "画像を削除しますか？",
+                                          "今後表示しない(常に削除) (_D)",
+                                          Gtk::MESSAGE_QUESTION,
+                                          Gtk::BUTTONS_YES_NO,
+                                          Gtk::RESPONSE_NO
+                );
+
+            if( mdiag.run() != Gtk::RESPONSE_YES ) return;
+            if( mdiag.get_chkbutton().get_active() ) CONFIG::set_show_delimgdiag( false );
+        }
+    }
+
     CORE::core_set_command( "delete_image", get_url() );
 }
 
 
+//
+// クリックした時の処理
+//
+void ImageViewBase::clicked()
+{
+    IMAGE::get_admin()->set_command( "switch_image", get_url() );
+    IMAGE::get_admin()->set_command( "switch_admin" );
+}
+
+
 
 //
 // viewの操作
 //
-void ImageViewBase::operate_view( const int& control )
+const bool ImageViewBase::operate_view( const int control )
 {
+    if( CONTROL::operate_common( control, get_url(), IMAGE::get_admin() ) ) return true;
+
 #ifdef _DEBUG
     std::cout << "ImageViewBase::operate_view control = " << control << std::endl;
 #endif
@@ -514,14 +677,7 @@ void ImageViewBase::operate_view( const int& control )
             close_view();
             break;
 
-        case CONTROL::TabLeft:
-            IMAGE::get_admin()->set_command( "tab_left" );
-            break;
-
-        case CONTROL::TabRight:
-            IMAGE::get_admin()->set_command( "tab_right" );
-            break;
-
+        // スクロール
         case CONTROL::ScrollUpImage:
             IMAGE::get_admin()->set_command( "scroll_up" );
             break;
@@ -548,36 +704,24 @@ void ImageViewBase::operate_view( const int& control )
             break;
 
         case CONTROL::Save:
+        case CONTROL::SaveImageButton:
             slot_save();
             break;
 
         case CONTROL::Delete:
-
-            if( !m_img->is_protected() ){
-
-                SKELETON::MsgDiag mdiag( IMAGE::get_admin()->get_win(),
-                                         "画像を削除しますか？", false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
-                mdiag.set_default_response( Gtk::RESPONSE_NO );
-                if( mdiag.run() == Gtk::RESPONSE_YES ) delete_view();
-            }
-            else{
-
-                SKELETON::MsgDiag mdiag( IMAGE::get_admin()->get_win(), "キャッシュ保護されています" );
-                mdiag.run();
-            }
-
+            delete_view_impl( true );
             break;
 
-            // サイドバー表示/非表示
-        case CONTROL::ShowSideBar:
-            CORE::core_set_command( "toggle_sidebar" );
+            // お気に入りに追加
+        case CONTROL::AppendFavorite:
+            slot_favorite();
             break;
 
-            // メニューバー表示/非表示
-        case CONTROL::ShowMenuBar:
-            CORE::core_set_command( "toggle_menubar" );
-            break;
+        default:
+            return false;
     }
+
+    return true;
 }
                                                     
 
@@ -587,15 +731,13 @@ void ImageViewBase::operate_view( const int& control )
 //
 // キープレスイベント
 //
-bool ImageViewBase::slot_key_press( GdkEventKey* event )
+const bool ImageViewBase::slot_key_press( GdkEventKey* event )
 {
 #ifdef _DEBUG
     std::cout << "ImageViewBase::slot_key_press url = " << get_url() << std::endl;
 #endif
 
-    operate_view( get_control().key_press( event ) );
-
-    return true;
+    return operate_view( get_control().key_press( event ) );
 }
 
 
@@ -621,11 +763,8 @@ bool ImageViewBase::slot_button_press( GdkEventButton* event )
     if( event->type == GDK_2BUTTON_PRESS ) m_dblclick = true; 
 
     // クリック
-    // 反応を良くするため slot_button_release() ではなくてここで処理する
-    if( get_control().button_alloted( event, CONTROL::ClickButton ) ){
-        IMAGE::get_admin()->set_command( "switch_image", get_url() );
-        IMAGE::get_admin()->set_command( "switch_admin" );
-    }
+    // 反応を良くするため slot_button_release() ではなくてボタンを押した時点で処理する
+    if( get_control().button_alloted( event, CONTROL::ClickButton ) ) clicked();
 
     return true;
 }
@@ -732,7 +871,10 @@ void ImageViewBase::slot_reload_force()
     if( ! m_enable_menuslot ) return;
 
     if( ! SESSION::is_online() ){
-        SKELETON::MsgDiag mdiag( NULL, "オフラインです" );
+
+        CORE::core_set_command( "hide_popup" );
+
+        SKELETON::MsgDiag mdiag( get_parent_win(), "オフラインです" );
         mdiag.run();
         return;
     }
@@ -742,7 +884,6 @@ void ImageViewBase::slot_reload_force()
     m_img->set_code( HTTP_INIT );
     m_img->set_type( DBIMG::T_UNKNOWN );
     reload();
-    CORE::core_set_command( "redraw", get_url() );
 }
 
 
@@ -754,9 +895,12 @@ void ImageViewBase::slot_cancel_mosaic()
     if( ! m_enable_menuslot ) return;
 
     if( ! m_img->is_cached() ) return;
+    if( ! m_img->get_mosaic() ) return;
 
     if( m_img->is_fake() ){
 
+        CORE::core_set_command( "hide_popup" );
+
         std::string type = "本当の画像タイプは";
         switch( DBIMG::get_type_real( get_url() ) ){
             case DBIMG::T_JPG: type += "JPEG"; break;
@@ -766,7 +910,7 @@ void ImageViewBase::slot_cancel_mosaic()
         }
         type += "です。";
 
-        SKELETON::MsgDiag mdiag( IMAGE::get_admin()->get_win(),
+        SKELETON::MsgDiag mdiag( get_parent_win(),
                                  "拡張子が偽装されています。" + type + "\n\nモザイクを解除しますか？",
                                  false, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO );
 
@@ -793,6 +937,7 @@ void ImageViewBase::slot_show_large_img()
 //
 void ImageViewBase::slot_fit_win()
 {
+    if( m_img->is_zoom_to_fit() ) SESSION::toggle_img_fit_mode();
     m_img->set_zoom_to_fit( true );
     CORE::core_set_command( "redraw", get_url() );
 }
@@ -896,12 +1041,22 @@ void ImageViewBase::slot_open_browser()
 {
     if( ! m_enable_menuslot ) return;
 
-    std::string url = get_url();
-    if( m_img->is_cached() ) url = "file://" + m_img->get_cache_path();
-    CORE::core_set_command( "open_url_browser", url );
+    CORE::core_set_command( "open_url_browser", get_url() );
 }
 
 
+//
+// キャッシュをブラウザで開く
+//
+void ImageViewBase::slot_open_cache_browser()
+{
+    if( ! m_enable_menuslot ) return;
+    if( ! m_img->is_cached() ) return;
+
+    const std::string url = "file://" + m_img->get_cache_path();
+    CORE::core_set_command( "open_url_browser", url );
+}
+
 
 //
 // 参照元を開く
@@ -940,12 +1095,13 @@ void ImageViewBase::slot_copy_url()
 
 
 //
-// 保存メニュー
+// 保存
 //
 void ImageViewBase::slot_save()
 {
     if( ! m_enable_menuslot ) return;
 
+    CORE::core_set_command( "hide_popup" );
     m_img->save( IMAGE::get_admin()->get_win(), std::string() );
 }
 
@@ -1004,11 +1160,14 @@ void ImageViewBase::set_image_to_buffer()
 {
     CORE::DATA_INFO info;
     info.type = TYPE_IMAGE;
+    info.parent = IMAGE::get_admin()->get_win();
     info.url = get_url();
     info.name = get_url();
+    info.path = Gtk::TreePath( "0" ).to_string();
 
-    CORE::SBUF_clear_info();
-    CORE::SBUF_append( info );
+    CORE::DATA_INFO_LIST list_info;
+    list_info.push_back( info );
+    CORE::SBUF_set_list( list_info );
 }
 
 
@@ -1079,6 +1238,13 @@ void ImageViewBase::activate_act_before_popupmenu( const std::string& url )
         }
     }
 
+    // キャッシュをブラウザで開く
+    act = action_group()->get_action( "OpenCacheBrowser" );
+    if( act ){
+        if( m_img->is_cached() ) act->set_sensitive( true );
+        else act->set_sensitive( false );
+    }
+
     // 参照元スレ
     act = action_group()->get_action( "OpenRef" );
     if( act ){
@@ -1124,6 +1290,29 @@ void ImageViewBase::activate_act_before_popupmenu( const std::string& url )
         else act->set_sensitive( false );
     }
 
+    // ユーザコマンド
+    // 選択不可かどうか判断して visible か sensitive にする
+    const std::string url_article = DBTREE::url_dat( m_img->get_refurl() );
+    CORE::get_usrcmd_manager()->toggle_sensitive( action_group(), url_article, get_url(), "" );
+
     m_enable_menuslot = true;
 }
 
+
+//
+// ユーザコマンド実行
+//
+void ImageViewBase::slot_usrcmd( int num )
+{
+    int from, to;
+    std::string num_str;
+    const std::string url_article = DBTREE::url_dat( m_img->get_refurl(), from, to, num_str );
+
+    CORE::core_set_command( "exec_usr_cmd" ,
+                            url_article,
+                            MISC::itostr( num ),
+                            get_url(),
+                            "",
+                            MISC::itostr( from )
+        );
+}
