@@ -2,6 +2,7 @@
 
 //#define _DEBUG
 //#define _DEBUG_CHUNKED
+//#define _DEBUG_TIME
 #ifdef _WIN32
 #define STRICT
 #endif
@@ -16,6 +17,12 @@
 #include "miscutil.h"
 #include "ssl.h"
 
+#ifdef _DEBUG_TIME
+#include "misctime.h"
+#endif
+
+#include "config/globalconf.h"
+
 #include "skeleton/loadable.h"
 
 #include "httpcode.h"
@@ -39,8 +46,8 @@ enum
 {
     MAX_LOADER = 10, // 最大スレッド数
     MAX_LOADER_SAMEHOST = 2, // 同一ホストに対して実行できる最大スレッド数
-    LNG_BUF_MIN = 16 * 1024, // 読み込みバッファの最小値 (byte)
-    TIMEOUT_MIN = 10 // タイムアウトの最小値 (秒)
+    LNG_BUF_MIN = 1 * 1024, // 読み込みバッファの最小値 (byte)
+    TIMEOUT_MIN = 1 // タイムアウトの最小値 (秒)
 };
 
 
@@ -91,7 +98,9 @@ const bool JDLIB::get_token( JDLIB::Loader* loader )
 #ifdef _DEBUG
     std::cout << "count = " << count << std::endl;
 #endif
-    if( count >= MAX_LOADER_SAMEHOST ) return false;
+
+    const int max_loader = MIN( MAX_LOADER_SAMEHOST, MAX( 1, CONFIG::get_connection_num() ) );
+    if( count >= max_loader ) return false;
 
 #ifdef _DEBUG
     std::cout << "got token\n";
@@ -698,14 +707,14 @@ void Loader::run_main()
             ssize_t tmpsize = send( soc, msg_send.data(), send_size,0);
             int lastError = WSAGetLastError();
 #else
-#ifndef NO_MSG_NOSIGNAL
-            ssize_t tmpsize = send( soc, msg_send.data(), send_size , MSG_NOSIGNAL );
+#ifdef MSG_NOSIGNAL
+            ssize_t tmpsize = send( soc, msg_send.data(), send_size, MSG_NOSIGNAL );
 #else
-            // SolarisにはMSG_NOSIGNALが無いのでSIGPIPEをIGNOREする
+            // SolarisにはMSG_NOSIGNALが無いのでSIGPIPEをIGNOREする (FreeBSD4.11Rにもなかった)
             signal( SIGPIPE , SIG_IGN ); /* シグナルを無視する */
             ssize_t tmpsize = send( soc, msg_send.data(), send_size,0);
             signal(SIGPIPE,SIG_DFL); /* 念のため戻す */
-#endif // NO_MSG_NOSIGNAL
+#endif // MSG_NOSIGNAL
 #endif // _WIN32
 
 #ifdef _WIN32
@@ -750,6 +759,10 @@ void Loader::run_main()
 
     bool receiving_header;
 
+#ifdef _DEBUG_TIME
+    MISC::start_measurement( 1 );
+#endif
+
     // 受信開始
     receiving_header = true;
     m_data.length_current = 0;
@@ -764,6 +777,10 @@ void Loader::run_main()
             // 通常
             if( !ssl ){
 
+#ifdef _DEBUG_TIME
+                MISC::start_measurement( 0 );
+#endif
+
                 // readfds 待ち
                 if( !wait_recv_send( soc, true ) ){
                     // タイムアウト
@@ -779,6 +796,9 @@ void Loader::run_main()
                     goto EXIT_LOADING;
                 }
 
+#ifdef _DEBUG_TIME
+                std::cout << "size = " << tmpsize << " time = " << MISC::measurement( 0 ) << std::endl;
+#endif
             }
 
             // SSL
@@ -876,6 +896,10 @@ void Loader::run_main()
         
     } while( !m_stop );
 
+#ifdef _DEBUG_TIME
+    std::cout << "loadingl time = " << MISC::measurement( 1 ) << std::endl;
+#endif
+
     // 終了処理
 EXIT_LOADING:
 
