@@ -12,6 +12,7 @@
 #include "skeleton/msgdiag.h"
 #include "skeleton/label_entry.h"
 #include "skeleton/editview.h"
+#include "skeleton/detaildiag.h"
 
 #include "jdlib/miscutil.h"
 #include "jdlib/misctime.h"
@@ -275,6 +276,8 @@ const bool MessageViewBase::set_command( const std::string& command, const std::
     else if( command == "tab_left" ) tab_left();
     else if( command == "tab_right" ) tab_right();
 
+    else if( command == "hide_popup" && m_preview ) m_preview->set_command( "hide_popup" );
+
     // メッセージをクリア
     else if( command == "clear_message" ){
 
@@ -349,6 +352,53 @@ void MessageViewBase::save_name()
 }
 
 
+//
+// 名前欄に名前をセット
+//
+void MessageViewBase::set_name()
+{
+    // スレ別の名前
+    if( DBTREE::write_fixname( get_url() ) ){
+        m_check_fixname.set_active();
+        m_entry_name.set_text( DBTREE::write_name( get_url() ) );
+    }
+    // スレ別の名前が設定されていなかったら板別の名前
+    else if( ! DBTREE::board_get_write_name( get_url() ).empty() ){
+
+        std::string tmpname = DBTREE::board_get_write_name( get_url() );
+
+        // 空白セット
+        if( tmpname == JD_NAME_BLANK ) m_entry_name.set_text( std::string() );
+        else m_entry_name.set_text( tmpname );
+    }
+    // デフォルトをセット
+    else m_entry_name.set_text( CONFIG::get_write_name() );
+}
+
+
+//
+// メール欄にアドレスをセット
+//
+void MessageViewBase::set_mail()
+{
+    // スレ別のメール
+    if( DBTREE::write_fixmail( get_url() ) ){
+        m_check_fixmail.set_active();
+        m_entry_mail.set_text( DBTREE::write_mail( get_url() ) );
+    }
+    // スレ別の名前が設定されていなかったら板別のメール
+    else if( ! DBTREE::board_get_write_mail( get_url() ).empty() ){
+
+        std::string tmpmail = DBTREE::board_get_write_mail( get_url() );
+
+        // 空白セット
+        if( tmpmail == JD_MAIL_BLANK ) m_entry_mail.set_text( std::string() );
+        else m_entry_mail.set_text( tmpmail );
+    }
+    // デフォルトをセット
+    else m_entry_mail.set_text( CONFIG::get_write_mail() );
+}
+
 
 //
 // ツールバーなどのパック
@@ -367,32 +417,8 @@ void MessageViewBase::pack_widget()
     m_tooltip.set_tip( m_check_fixname, "チェックすると名前欄を保存して固定にする" );
     m_tooltip.set_tip( m_check_fixmail, "チェックするとメール欄を保存して固定にする" );
 
-    // スレ別の名前
-    if( DBTREE::write_fixname( get_url() ) ){
-        m_check_fixname.set_active();
-        m_entry_name.set_text( DBTREE::write_name( get_url() ) );
-    }
-    // スレ別の名前が設定されていなかったら板別の名前
-    else if( ! DBTREE::board_get_write_name( get_url() ).empty() ){
-        m_entry_name.set_text( DBTREE::board_get_write_name( get_url() ) );
-    }
-
-    // スレ別のメール
-    if( DBTREE::write_fixmail( get_url() ) ){
-        m_check_fixmail.set_active();
-        m_entry_mail.set_text( DBTREE::write_mail( get_url() ) );
-    }
-    // スレ別の名前が設定されていなかったら板別のメール
-    else if( ! DBTREE::board_get_write_mail( get_url() ).empty() ){
-
-        std::string tmpmail = DBTREE::board_get_write_mail( get_url() );
-
-        // 空白セット
-        if( tmpmail == JD_MAIL_BLANK ) m_entry_mail.set_text( std::string() );
-        else m_entry_mail.set_text( tmpmail );
-    }
-    // デフォルトはsage
-    else m_entry_mail.set_text( "sage" );
+    set_name();
+    set_mail();
 
     m_tool_name.add( m_label_name );
     m_tool_mail.add( m_label_mail );
@@ -524,6 +550,11 @@ const bool MessageViewBase::operate_view( const int control )
             MESSAGE::get_admin()->set_command( "tab_right" );
             break;
 
+        case CONTROL::ToggleSage:
+            if( m_entry_mail.get_text() == "sage" ) m_entry_mail.set_text( "" );
+            else set_mail();
+            break;
+
             // 書き込みボタンにフォーカスを移す
         case CONTROL::FocusWrite:
             MESSAGE::get_admin()->set_command( "focus_button_write" );
@@ -815,9 +846,13 @@ void MessageViewBase::post_fin()
     // 失敗
     else if( code != HTTP_CANCEL ){
 
-        SKELETON::MsgDiag mdiag( get_parent_win(),
-                                 "書き込みに失敗しました\n\n" + m_post->errmsg(), false, Gtk::MESSAGE_ERROR  );
-        mdiag.run();
+        SKELETON::DetailDiag ddiag( get_parent_win(), get_url(),
+                          false,
+                          "書き込みに失敗しました\n\n" + m_post->get_errmsg(), "概要",
+                          m_post->get_return_html(), "詳細" );
+
+        ddiag.set_title( "書き込みエラー" );
+        ddiag.run();
     }
 }
 
