@@ -19,6 +19,8 @@
 
 bool booting = true;
 bool quitting = false;
+bool tab_operating_article = false;
+bool tab_operating_image = false;
 
 int mode_pane;
 bool mode_online;
@@ -56,6 +58,9 @@ std::vector< int > items_main_toolbar;
 std::string items_article_toolbar_str;
 std::vector< int > items_article_toolbar;
 
+std::string items_search_toolbar_str;
+std::vector< int > items_search_toolbar;
+
 std::string items_board_toolbar_str;
 std::vector< int > items_board_toolbar;
 
@@ -175,6 +180,8 @@ const int SESSION::parse_item( const std::string& item_name )
     else if( item_name == ITEM_NAME_HISTVIEW ) item = ITEM_HISTVIEW;
     else if( item_name == ITEM_NAME_HIST_BOARDVIEW ) item = ITEM_HIST_BOARDVIEW;
     else if( item_name == ITEM_NAME_HIST_CLOSEVIEW ) item = ITEM_HIST_CLOSEVIEW;
+    else if( item_name == ITEM_NAME_HIST_CLOSEBOARDVIEW ) item = ITEM_HIST_CLOSEBOARDVIEW;
+    else if( item_name == ITEM_NAME_HIST_CLOSEIMGVIEW ) item = ITEM_HIST_CLOSEIMGVIEW;
     else if( item_name == ITEM_NAME_ARTICLEVIEW ) item = ITEM_ARTICLEVIEW;
     else if( item_name == ITEM_NAME_IMAGEVIEW ) item = ITEM_IMAGEVIEW;
     else if( item_name == ITEM_NAME_URL ) item = ITEM_URL;
@@ -202,7 +209,7 @@ const int SESSION::parse_item( const std::string& item_name )
     else if( item_name == ITEM_NAME_DRAWOUT ) item = ITEM_DRAWOUT;
     else if( item_name == ITEM_NAME_RELOAD ) item = ITEM_RELOAD;
     else if( item_name == ITEM_NAME_STOPLOADING ) item = ITEM_STOPLOADING;
-    else if( item_name == ITEM_NAME_FAVORITE ) item = ITEM_FAVORITE;
+    else if( item_name == ITEM_NAME_APPENDFAVORITE ) item = ITEM_APPENDFAVORITE;
     else if( item_name == ITEM_NAME_FAVORITE_ARTICLE ) item = ITEM_FAVORITE_ARTICLE;
     else if( item_name == ITEM_NAME_CHECK_UPDATE_ROOT ) item = ITEM_CHECK_UPDATE_ROOT;
     else if( item_name == ITEM_NAME_CHECK_UPDATE_OPEN_ROOT ) item = ITEM_CHECK_UPDATE_OPEN_ROOT;
@@ -215,8 +222,8 @@ const int SESSION::parse_item( const std::string& item_name )
 
     else if( item_name == ITEM_NAME_DELETE ) item = ITEM_DELETE;
     else if( item_name == ITEM_NAME_QUIT ) item = ITEM_QUIT;
-    else if( item_name == ITEM_NAME_PREVVIEW ) item = ITEM_PREVVIEW;
-    else if( item_name == ITEM_NAME_NEXTVIEW ) item = ITEM_NEXTVIEW;
+    else if( item_name == ITEM_NAME_BACK ) item = ITEM_BACK;
+    else if( item_name == ITEM_NAME_FORWARD ) item = ITEM_FORWARD;
     else if( item_name == ITEM_NAME_LOCK ) item = ITEM_LOCK;
     else if( item_name == ITEM_NAME_LIVE ) item = ITEM_LIVE;
 
@@ -225,6 +232,7 @@ const int SESSION::parse_item( const std::string& item_name )
     else if( item_name == ITEM_NAME_SEARCH_NEXT ) item = ITEM_SEARCH_NEXT;
     else if( item_name == ITEM_NAME_SEARCH_PREV ) item = ITEM_SEARCH_PREV;
     else if( item_name == ITEM_NAME_NEXTARTICLE ) item = ITEM_NEXTARTICLE;
+    else if( item_name == ITEM_NAME_CLEAR_HIGHLIGHT ) item = ITEM_CLEAR_HIGHLIGHT;
 
     else if( item_name == ITEM_NAME_INSERTTEXT ) item = ITEM_INSERTTEXT;
     else if( item_name == ITEM_NAME_LOCK_MESSAGE ) item = ITEM_LOCK_MESSAGE;
@@ -381,6 +389,10 @@ void SESSION::init_session()
     items_article_toolbar_str = cf.get_option_str( "items_article_toolbar", get_items_article_toolbar_default_str() );
     items_article_toolbar =  parse_items( items_article_toolbar_str );
 
+    // 検索ビューのツールバーの項目
+    items_search_toolbar_str = cf.get_option_str( "items_search_toolbar", get_items_search_toolbar_default_str() );
+    items_search_toolbar =  parse_items( items_search_toolbar_str );
+
     // スレ一覧のツールバー項目
     items_board_toolbar_str = cf.get_option_str( "items_board_toolbar", get_items_board_toolbar_default_str() );
     items_board_toolbar =  parse_items( items_board_toolbar_str );
@@ -606,6 +618,7 @@ void SESSION::save_session()
         << "items_sidebar = " << items_sidebar_toolbar_str << std::endl
         << "items_main_toolbar = " << items_main_toolbar_str << std::endl
         << "items_article_toolbar = " << items_article_toolbar_str << std::endl
+        << "items_search_toolbar = " << items_search_toolbar_str << std::endl
         << "items_board_toolbar = " << items_board_toolbar_str << std::endl
         << "items_msg_toolbar = " << items_msg_toolbar_str << std::endl
         << "items_board = " << items_board_col_str << std::endl
@@ -664,6 +677,22 @@ void SESSION::set_booting( const bool boot ){ booting = boot; }
 const bool SESSION::is_quitting(){ return quitting; }
 void SESSION::set_quitting( const bool quit ){ quitting = quit; }
 
+// 入れ替えなどのタブ操作中
+// ビューの再描画などを禁止する
+const bool SESSION::is_tab_operating( const std::string& url_admin )
+{
+    if( url_admin == URL_ARTICLEADMIN ) return tab_operating_article;
+    if( url_admin == URL_IMAGEADMIN ) return tab_operating_image;
+
+    return false;
+}
+
+void SESSION::set_tab_operating( const std::string& url_admin, const bool operating )
+{
+    if( url_admin == URL_ARTICLEADMIN ) tab_operating_article = operating;
+    if( url_admin == URL_IMAGEADMIN ) tab_operating_image = operating;
+}
+
 const int SESSION::get_mode_pane() { return mode_pane; }
 void SESSION::set_mode_pane( const int mode ){ mode_pane = mode; }
 
@@ -902,7 +931,7 @@ const std::string SESSION::get_items_article_toolbar_default_str()
     ITEM_NAME_SEARCH + std::string ( " " ) +
     ITEM_NAME_RELOAD + std::string ( " " ) +
     ITEM_NAME_STOPLOADING + std::string ( " " ) +
-    ITEM_NAME_FAVORITE + std::string ( " " ) +
+    ITEM_NAME_APPENDFAVORITE + std::string ( " " ) +
     ITEM_NAME_DELETE + std::string ( " " ) +
     ITEM_NAME_QUIT;
 }
@@ -913,6 +942,24 @@ void SESSION::set_items_article_toolbar_str( const std::string& items_str )
 }
 const int SESSION::get_item_article_toolbar( const int num ){ return items_article_toolbar[ num ]; }
 
+// 検索ビューのツールバーの項目
+const std::string& SESSION::get_items_search_toolbar_str(){ return items_search_toolbar_str; }
+const std::string SESSION::get_items_search_toolbar_default_str()
+{
+    return
+    ITEM_NAME_NAME + std::string ( " " ) +
+    ITEM_NAME_SEARCH + std::string ( " " ) +
+    ITEM_NAME_RELOAD + std::string ( " " ) +
+    ITEM_NAME_STOPLOADING + std::string ( " " ) +
+    ITEM_NAME_QUIT;
+}
+void SESSION::set_items_search_toolbar_str( const std::string& items_str )
+{
+    items_search_toolbar_str = items_str;
+    items_search_toolbar = parse_items( items_search_toolbar_str );
+}
+const int SESSION::get_item_search_toolbar( const int num ){ return items_search_toolbar[ num ]; }
+
 // スレ一覧のツールバー項目
 const std::string& SESSION::get_items_board_toolbar_str(){ return items_board_toolbar_str; }
 const std::string SESSION::get_items_board_toolbar_default_str()
@@ -924,7 +971,7 @@ const std::string SESSION::get_items_board_toolbar_default_str()
     ITEM_NAME_SEARCH_PREV + std::string ( " " ) +
     ITEM_NAME_RELOAD + std::string ( " " ) +
     ITEM_NAME_STOPLOADING + std::string ( " " ) +
-    ITEM_NAME_FAVORITE + std::string ( " " ) +
+    ITEM_NAME_APPENDFAVORITE + std::string ( " " ) +
     ITEM_NAME_DELETE + std::string ( " " ) +
     ITEM_NAME_QUIT;
 }
