@@ -85,7 +85,7 @@ Admin::~Admin()
     // デストラクタの中からdispatchを呼ぶと落ちるので dispatch不可にする
     set_dispatchable( false );
 
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
 
 #ifdef _DEBUG
     std::cout << "pages = " << pages << std::endl;
@@ -96,7 +96,7 @@ Admin::~Admin()
 
             SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( 0 ) );
 
-            m_notebook->remove_page( 0 );
+            m_notebook->remove_page( 0, false );
 
             if( view ) delete view;
         }
@@ -140,6 +140,7 @@ void Admin::setup_menu()
     m_action_group->add( Gtk::Action::create( "CloseLeft", "左←のタブ(_L)" ), sigc::mem_fun( *this, &Admin::slot_close_left_tabs ) );
     m_action_group->add( Gtk::Action::create( "CloseRight", "右→のタブ(_R)" ), sigc::mem_fun( *this, &Admin::slot_close_right_tabs ) );
     m_action_group->add( Gtk::Action::create( "CloseAll", "全てのタブ(_A)" ), sigc::mem_fun( *this, &Admin::slot_close_all_tabs ) );
+    m_action_group->add( Gtk::Action::create( "CloseSameIcon", "同じアイコンのタブ(_I)" ), sigc::mem_fun( *this, &Admin::slot_close_same_icon_tabs ) );
 
     m_action_group->add( Gtk::Action::create( "Reload_Tab_Menu", "全てのタブの再読み込み(_A)" ) );
     m_action_group->add( Gtk::Action::create( "CheckUpdateAll", "更新チェックのみ(_U)" ), sigc::mem_fun( *this, &Admin::slot_check_update_all_tabs ) );
@@ -184,6 +185,7 @@ void Admin::setup_menu()
     "<menuitem action='CloseOther'/>"
     "<menuitem action='CloseLeft'/>"
     "<menuitem action='CloseRight'/>"
+    "<menuitem action='CloseSameIcon'/>"
     "</menu>"
     "<separator/>"
 
@@ -346,7 +348,7 @@ void Admin::clock_in()
 
     // 全てのビューにクロックを送る
     // clock_in_always()には軽い処理だけを含めること
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
         for( int i = 0; i < pages; ++i ){
             SKELETON::View* view = dynamic_cast< SKELETON::View* >( m_notebook->get_nth_page( i ) );
@@ -423,10 +425,13 @@ void Admin::set_command_immediately( const std::string& command, const std::stri
 void Admin::set_command_impl( const bool immediately, const COMMAND_ARGS& command_arg )
 {
 #ifdef _DEBUG
-    std::cout << "Admin::set_command : immediately = " << immediately <<  " command = " << command << " url = " << url << std::endl
-              << arg1 << " " << arg2 << std::endl
-              << arg3 << " " << arg4 << std::endl
-              << arg5 << " " << arg6 << std::endl;
+    std::cout << "Admin::set_command : immediately = " << immediately
+              <<  " command = " << command_arg.command
+              << " url = " << command_arg.url << std::endl
+              << command_arg.arg1 << " " << command_arg.arg2 << std::endl
+              << command_arg.arg3 << " " << command_arg.arg4 << std::endl
+              << command_arg.arg5 << " " << command_arg.arg6 << std::endl
+              << command_arg.arg7 << " " << command_arg.arg8 << std::endl;
 #endif
 
     if( immediately ){
@@ -523,6 +528,29 @@ void Admin::exec_command()
     else if( command.command == "tab_tail" ){
         tab_tail();
     }
+
+    else if( command.command == "set_tab_operating" ){
+
+#ifdef _DEBUG
+        std::cout << command.command << " " << m_url << " " << command.arg1 << std::endl;
+#endif
+
+        if( command.arg1 == "true" ) SESSION::set_tab_operating( m_url, true );
+        else{
+
+            SESSION::set_tab_operating( m_url, false );
+
+            if( ! empty() ){
+
+                // 現在開いているタブへの switch 処理
+                const bool focus_tmp = m_focus;
+                m_focus = true;
+                slot_switch_page( NULL,  m_notebook->get_current_page() );
+                m_focus = focus_tmp;
+            }
+        }
+
+    }
     else if( command.command == "redraw" ){
         redraw_view( command.url );
     }
@@ -562,6 +590,11 @@ void Admin::exec_command()
         close_current_view();
     }
 
+    // 最後に閉じたタブを復元する
+    else if( command.command == "restore_lasttab" ){
+        restore_lasttab();
+    }
+
     else if( command.command == "set_page" ){
         set_current_page( atoi( command.arg1.c_str() ) );
     }
@@ -707,6 +740,11 @@ void Admin::exec_command()
     }
 
     // プロパティ表示
+    else if( command.command == "show_preferences" ){
+        SKELETON::View* view = get_view( command.url );
+        if( view ) view->show_preference();
+    }
+
     else if( command.command == "show_current_preferences" ){
         SKELETON::View* view = get_current_view();
         if( view ) view->show_preference();
@@ -743,6 +781,9 @@ void Admin::exec_command()
         set_autoreload_mode( command.url, AUTORELOAD_NOT, 0 );
     }
 
+    // ポップアップを隠す(インスタンスは削除しない)
+    else if( command.command == "hide_popup" ) hide_popup();
+
     else{
 
         // ツールバー関係
@@ -792,6 +833,8 @@ void Admin::open_list( const COMMAND_ARGS& command_list )
     int waittime = 0;
     const bool online = SESSION::is_online();
 
+    SESSION::set_tab_operating( m_url, true );
+
     std::list< std::string >::iterator it = list_url.begin();
     for( ; it != list_url.end(); ++it, waittime += AUTORELOAD_MINSEC ){
 
@@ -822,6 +865,8 @@ void Admin::open_list( const COMMAND_ARGS& command_list )
 
     SESSION::set_online( online );
 
+    set_command( "set_tab_operating", "", "false" );
+
     switch_admin();
     switch_view( *( list_url.begin() ) );
 }
@@ -836,7 +881,7 @@ void Admin::update_url( const std::string& url_old, const std::string& url_new )
     std::cout << "Admin::update_url " << url_old << " -> " << url_new << std::endl;
 #endif
 
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
 
         for( int i = 0; i < pages; ++i ){
@@ -856,7 +901,7 @@ void Admin::update_boardname( const std::string& url )
     std::cout << "Admin::update_boardname url = " << url << std::endl;
 #endif
 
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
 
         for( int i = 0; i < pages; ++i ){
@@ -1034,10 +1079,14 @@ void Admin::open_view( const COMMAND_ARGS& command )
 #ifdef _DEBUG
         std::cout << "replace page\n";
 #endif
+
+        // タブを入れ替えたときに隣のタブの再描画を防ぐ
+        set_command_immediately( "set_tab_operating", "", "true" );
+
         // タブ入れ替え
         m_notebook->insert_page( command.url, *view, page );
 
-        m_notebook->remove_page( page + 1 );
+        m_notebook->remove_page( page + 1, false );
 
         if( current_view ){
 
@@ -1058,6 +1107,12 @@ void Admin::open_view( const COMMAND_ARGS& command )
             }
 
         }
+
+#ifdef _DEBUG
+        std::cout << "replace done\n";
+#endif
+
+        set_command( "set_tab_operating", "", "false" );
     }
 
     m_notebook->show_all();
@@ -1187,7 +1242,7 @@ void Admin::tab_left( const bool updated )
 //
 void Admin::tab_right( const bool updated )
 {
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages == 1 ) return;
 
     int page = m_notebook->get_current_page();
@@ -1244,7 +1299,7 @@ void Admin::tab_num( const std::string& str_num )
 //
 void Admin::tab_head()
 {
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages == 1 ) return;
 
     set_current_page( 0 );
@@ -1266,7 +1321,7 @@ void Admin::tab_head_focus()
 //
 void Admin::tab_tail()
 {
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages == 1 ) return;
 
     set_current_page( pages-1 );
@@ -1377,7 +1432,7 @@ void Admin::close_view( SKELETON::View* view )
         if( newview ) switch_view( newview->get_url() );
     }
 
-    m_notebook->remove_page( page );
+    m_notebook->remove_page( page, true );
 
     if( m_use_viewhistory ){
 
@@ -1805,6 +1860,13 @@ bool Admin::set_autoreload_mode( const std::string& url, int mode, int sec )
 }
 
 
+// ポップアップを隠す(インスタンスは削除しない)
+void Admin::hide_popup()
+{
+    SKELETON::View* view = get_current_view();
+    if( view ) view->set_command( "hide_popup" );
+}
+
 
 //
 // ビュークラス取得
@@ -1814,7 +1876,7 @@ View* Admin::get_view( const std::string& url )
     SKELETON::View* view = get_current_view();
     if( view && view->get_url() == url ) return view;
 
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
 
         for( int i = 0; i < pages; ++i ){
@@ -1837,7 +1899,7 @@ std::list< View* > Admin::get_list_view( const std::string& url )
 {
     std::list< View* > list_view;
     
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
 
         for( int i = 0; i < pages; ++i ){
@@ -1859,7 +1921,7 @@ std::list< View* > Admin::get_list_view()
 {
     std::list< View* > list_view;
     
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
 
         for( int i = 0; i < pages; ++i ){
@@ -1937,8 +1999,11 @@ void Admin::slot_switch_page( GtkNotebookPage*, guint page )
     if( SESSION::is_booting() ) return;
     if( SESSION::is_quitting() ) return;
 
+    // タブ操作中
+    if( SESSION::is_tab_operating( m_url ) ) return;
+
 #ifdef _DEBUG
-    std::cout << "Admin::slot_switch_page : " << m_url << " page = " << page << std::endl;
+    std::cout << "Admin::slot_switch_page : " << m_url << " page = " << page << " focus = " << m_focus << std::endl;
 #endif
 
     SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( page ) );
@@ -2163,11 +2228,15 @@ void Admin::slot_close_other_tabs()
     std::cout << "Admin::slot_close_other_tabs " << m_clicked_page << std::endl;
 #endif
 
+    set_command( "set_tab_operating", "", "true" );
+
     std::string url;
     SKELETON::View* view =  dynamic_cast< View* >( m_notebook->get_nth_page( m_clicked_page ) );
     if( view ) url = view->get_url();
 
     close_other_views( url );
+
+    set_command( "set_tab_operating", "", "false" );
 }
 
 
@@ -2181,10 +2250,14 @@ void Admin::slot_close_left_tabs()
     std::cout << "Admin::slot_close_left_tabs " << m_clicked_page << std::endl;
 #endif
 
+    set_command( "set_tab_operating", "", "true" );
+
     for( int i = 0; i < m_clicked_page; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
         if( view ) set_command( "close_view", view->get_url() );
     }
+
+    set_command( "set_tab_operating", "", "false" );
 }
 
 
@@ -2197,11 +2270,15 @@ void Admin::slot_close_right_tabs()
     std::cout << "Admin::slot_close_right_tabs " << m_clicked_page << std::endl;
 #endif
 
-    int pages = m_notebook->get_n_pages();
+    set_command( "set_tab_operating", "", "true" );
+
+    const int pages = m_notebook->get_n_pages();
     for( int i = m_clicked_page +1; i < pages; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
         if( view ) set_command( "close_view", view->get_url() );
     }
+
+    set_command( "set_tab_operating", "", "false" );
 }
 
 
@@ -2216,11 +2293,42 @@ void Admin::slot_close_all_tabs()
     std::cout << "Admin::slot_close_all_tabs " << m_clicked_page << std::endl;
 #endif
 
-    int pages = m_notebook->get_n_pages();
+    set_command( "set_tab_operating", "", "true" );
+
+    const int pages = m_notebook->get_n_pages();
     for( int i = 0; i < pages; ++i ){
         SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
         if( view ) set_command( "close_view", view->get_url() );
     }
+
+    set_command( "set_tab_operating", "", "false" );
+}
+
+
+//
+// 右クリックメニューの同じアイコンのタブを閉じる
+//
+void Admin::slot_close_same_icon_tabs()
+{
+    const int id = get_notebook()->get_tabicon( m_clicked_page );
+
+#ifdef _DEBUG
+    std::cout << "Admin::slot_close_same_icon_tabs page = " << m_clicked_page << " id = " << id << std::endl;
+#endif
+
+    set_command( "set_tab_operating", "", "true" );
+
+    const int pages = m_notebook->get_n_pages();
+    for( int i = 0; i < pages; ++i ){
+
+        if( get_notebook()->get_tabicon( i ) == id ){
+
+            SKELETON::View* view = dynamic_cast< View* >( m_notebook->get_nth_page( i ) );
+            if( view ) set_command( "close_view", view->get_url() );
+        }
+    }
+
+    set_command( "set_tab_operating", "", "false" );
 }
 
 
@@ -2262,7 +2370,7 @@ void Admin::check_update_all_tabs( const int from_page, const bool open )
 
     if( ! SESSION::is_online() ) return;
 
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
 
     // 開始タブから右側
     for( int i = from_page ; i < pages; ++i ){
@@ -2314,7 +2422,7 @@ void Admin::reload_all_tabs( const int from_page )
     if( ! SESSION::is_online() ) return;
 
     int waittime = 0;
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
 
     // クリックしたタブから右側
     for( int i = from_page ; i < pages; ++i ){
@@ -2391,7 +2499,7 @@ std::list< bool > Admin::get_locked()
 {
     std::list< bool > locked;
     
-    int pages = m_notebook->get_n_pages();
+    const int pages = m_notebook->get_n_pages();
     if( pages ){
         for( int i = 0; i < pages; ++i ) locked.push_back( is_locked( i ) );
     }
