@@ -192,6 +192,7 @@ namespace SKELETON
         virtual void close_all_view( const std::string& url );
         virtual void close_other_views( const std::string& url );
         virtual void close_current_view();
+        virtual void restore_lasttab(){}
         virtual void set_title( const std::string& url, const std::string& title, const bool force );
         virtual void set_url( const std::string& url, const std::string& url_show, const bool force );
         virtual void set_status( const std::string& url, const std::string& stat, const bool force );
@@ -210,6 +211,9 @@ namespace SKELETON
         // オートリロードのモード設定
         virtual bool set_autoreload_mode( const std::string& url, int mode, int sec );
 
+        // ポップアップを隠す(インスタンスは削除しない)
+        void hide_popup();
+        
         // タブをお気に入りにドロップした時にお気に入りがデータ送信を要求してきた
         virtual void slot_drag_data_get( Gtk::SelectionData& selection_data, const int page ) = 0;
 
@@ -272,6 +276,7 @@ namespace SKELETON
         virtual void slot_close_left_tabs();
         virtual void slot_close_right_tabs();
         virtual void slot_close_all_tabs();
+        virtual void slot_close_same_icon_tabs();
         virtual void slot_check_update_all_tabs();
         virtual void slot_check_update_reload_all_tabs();
         virtual void slot_reload_all_tabs();
