@@ -10,6 +10,8 @@
 
 #include "dbtree/interface.h"
 
+#include "config/globalconf.h"
+
 #include "xml/document.h"
 
 #include "sharedbuffer.h"
@@ -32,6 +34,135 @@ enum
 };
 
 
+
+//
+// 行の最新アドレスを取得
+//
+const std::string get_uptodate_url( const std::string& url_org, const int type )
+{
+    std::string url = url_org;
+
+    if( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ){
+
+        url = DBTREE::url_boardbase( url );
+    }
+    else if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE || type == TYPE_THREAD_OLD ){
+
+        url = DBTREE::url_dat( url );
+    }
+
+    return url;
+}
+
+
+//
+// 行の最新状態を取得
+//
+const int get_uptodate_type( const std::string& url, const int type_org )
+{
+    int type = type_org;
+
+    if( type == TYPE_BOARD || type == TYPE_BOARD_UPDATE ){
+
+        if( DBTREE::board_status( url ) & STATUS_UPDATE ) type = TYPE_BOARD_UPDATE;
+        else if( type != TYPE_BOARD ) type = TYPE_BOARD;
+    }
+    else if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE || type == TYPE_THREAD_OLD ){
+
+        if( DBTREE::article_status( url ) & STATUS_OLD ) type = TYPE_THREAD_OLD;
+        else if( DBTREE::article_status( url ) & STATUS_UPDATE ) type = TYPE_THREAD_UPDATE;
+        else if( type != TYPE_THREAD ) type = TYPE_THREAD;
+    }
+
+    return type;
+}
+
+
+//
+// ソート用比較クラス
+//
+// EditTreeView::sort()で使用
+//
+class compare_path
+{
+    SKELETON::JDTreeViewBase& m_treeview;
+    SKELETON::EditColumns& m_columns;
+    int m_mode;
+
+    const int type_to_order( const int type )
+    {
+        int order[]={
+
+            TYPE_DIR,
+
+            TYPE_VBOARD,
+
+            TYPE_BOARD_UPDATE,
+            TYPE_BOARD,
+
+            TYPE_THREAD_UPDATE,
+            TYPE_THREAD,
+
+            TYPE_IMAGE,
+
+            TYPE_COMMENT,
+
+            TYPE_THREAD_OLD,
+
+            TYPE_UNKNOWN
+        };
+
+        int i = 0;
+        for( ; order[ i ] != TYPE_UNKNOWN; ++i ){
+
+            if( type == order[ i ] ) return i;
+        }
+
+        return i;
+    }
+
+public:
+
+    compare_path( SKELETON::JDTreeViewBase& treeview, SKELETON::EditColumns& columns, const int mode )
+        : m_treeview( treeview ), m_columns( columns ), m_mode( mode ){}
+
+    // path_a が上ならtrue　path_b　が上ならfalse
+    bool operator () ( const Gtk::TreePath& path_a, const Gtk::TreePath& path_b )
+    {
+        const Gtk::TreeRow row_a = m_treeview.get_row( path_a );
+        const Gtk::TreeRow row_b = m_treeview.get_row( path_b );
+
+        if( ! row_a || ! row_b ) return false;
+
+        // 名前でソート
+        if( m_mode == SKELETON::SORT_BY_NAME ){
+
+            const Glib::ustring name_a = row_a[ m_columns.m_name ];
+            const Glib::ustring name_b = row_b[ m_columns.m_name ];
+
+            if( name_a > name_b ) return false;
+            else if( name_a < name_b ) return true;
+        }
+
+        // タイプでソート
+        const Glib::ustring url_a = row_a[ m_columns.m_url ];
+        const Glib::ustring url_b = row_b[ m_columns.m_url ];
+
+        const int type_a = get_uptodate_type( url_a.raw(), row_a[ m_columns.m_type ] );
+        const int type_b = get_uptodate_type( url_b.raw(), row_b[ m_columns.m_type ] );
+
+        const int order_a = type_to_order( type_a );
+        const int order_b = type_to_order( type_b );
+
+        if( order_a == order_b ) return false;
+        return ( order_a < order_b );
+    }
+};
+
+
+/////////////////////////////////////////////////
+
+
 using namespace SKELETON;
 
 
@@ -225,6 +356,10 @@ void EditTreeView::xml2tree( XML::Document& document, Glib::RefPtr< Gtk::TreeSto
     set_treestore( treestore );
 #endif
 
+    // ディレクトリIDのセット(まだセットされていない場合)
+    get_max_dirid();
+    set_dirid();
+
     // ディレクトリオープン
     std::list< Gtk::TreePath >::iterator it_path = list_path_expand.begin();
     while( it_path != list_path_expand.end() )
@@ -261,6 +396,60 @@ void EditTreeView::tree2xml( XML::Document& document, const std::string& root_na
 }
 
 
+// ディレクトリIDの最大値を取得
+void EditTreeView::get_max_dirid()
+{
+    m_max_dirid = 0;
+
+    SKELETON::EditTreeViewIterator it( *this, m_columns, Gtk::TreePath() );
+    for( ; ! it.end(); ++it ){
+
+        Gtk::TreeModel::Row row = *it;
+
+        if( row[ m_columns.m_type ] == TYPE_DIR ){
+
+            const size_t dirid = row[ m_columns.m_dirid ];
+            if( dirid > m_max_dirid ) m_max_dirid = dirid;
+        }
+    }
+
+    ++m_max_dirid;
+
+#ifdef _DEBUG
+    std::cout << "EditTreeView::get_max_dirid id = " << m_max_dirid << std::endl;
+#endif
+}
+
+
+// IDがついていないディレクトリにIDをセットする
+void EditTreeView::set_dirid()
+{
+#ifdef _DEBUG
+    std::cout << "EditTreeView::set_dirid\n";
+#endif
+
+    SKELETON::EditTreeViewIterator it( *this, m_columns, Gtk::TreePath() );
+    for( ; ! it.end(); ++it ){
+
+        Gtk::TreeModel::Row row = *it;
+
+        if( row[ m_columns.m_type ] == TYPE_DIR ){
+
+            const size_t dirid = row[ m_columns.m_dirid ];
+            if( ! dirid ){
+
+                row[ m_columns.m_dirid ] = m_max_dirid++;
+
+#ifdef _DEBUG
+                std::cout << row[ m_columns.m_name ] << " id = " << row[ m_columns.m_dirid ] << std::endl;
+#endif
+            }
+        }
+    }
+}
+
+
+
 //
 // 全てのツリーに m_columns.m_expand の値をセットする( tree2xml()で使用 )
 //
@@ -300,7 +489,7 @@ Gtk::TreeViewColumn* EditTreeView::create_column( const int ypad )
     m_ren_text->property_underline() = Pango::UNDERLINE_SINGLE;
 
     // 行間スペース
-    if( ypad ) m_ren_text->property_ypad() = ypad;
+    if( ypad >= 0 ) m_ren_text->property_ypad() = ypad;
 
     col->pack_start( *m_ren_text, true );
     col->add_attribute( *m_ren_text, "text", EDITCOL_NAME );
@@ -326,11 +515,12 @@ const Gtk::TreePath EditTreeView::create_newdir( const Gtk::TreePath& path )
     CORE::DATA_INFO_LIST list_info;
     CORE::DATA_INFO info;
     info.type = TYPE_DIR;
-    info.parent = NULL;
-    info.url = std::string();
     info.name = "新規ディレクトリ";
-    info.data = std::string();
     info.path = path.to_string();
+
+    while( ! dirid_to_path( m_max_dirid ).empty() ) ++m_max_dirid;
+    info.dirid = m_max_dirid;
+
     list_info.push_back( info );
 
     const bool before = false;
@@ -338,7 +528,8 @@ const Gtk::TreePath EditTreeView::create_newdir( const Gtk::TreePath& path )
     const bool force = false;
     //  append_info 内でundoのコミットをしないで名前を変更してからslot_ren_text_on_canceled()でコミットする
     const bool cancel_undo_commit = true; 
-    append_info( list_info, path, before, scroll, force, cancel_undo_commit );
+    const int check_dup = 0; // 項目の重複チェックをしない
+    append_info( list_info, path, before, scroll, force, cancel_undo_commit, check_dup );
 
     Gtk::TreePath path_new = get_current_path();
     set_cursor( path_new );
@@ -348,6 +539,35 @@ const Gtk::TreePath EditTreeView::create_newdir( const Gtk::TreePath& path )
 }
 
 
+// ディレクトリIDとパスを相互変換
+const Gtk::TreePath EditTreeView::dirid_to_path( const size_t dirid )
+{
+    if( ! dirid ) return Gtk::TreePath();
+
+    SKELETON::EditTreeViewIterator it( *this, m_columns, Gtk::TreePath() );
+    for( ; ! it.end(); ++it ){
+
+        Gtk::TreeModel::Row row = *it;
+
+        if( row[ m_columns.m_type ] == TYPE_DIR ){
+
+            if( row[ m_columns.m_dirid ] == dirid ) return get_model()->get_path( row );
+        }
+    }
+
+    return Gtk::TreePath();
+}
+
+
+const size_t EditTreeView::path_to_dirid( const Gtk::TreePath path )
+{
+    Gtk::TreeModel::Row row = get_row( Gtk::TreePath( path ) );
+    if( row ) return row[ m_columns.m_dirid ];
+
+    return 0;
+}
+
+
 //
 // コメント挿入
 //
@@ -356,10 +576,7 @@ const Gtk::TreePath EditTreeView::create_newcomment( const Gtk::TreePath& path )
     CORE::DATA_INFO_LIST list_info;
     CORE::DATA_INFO info;
     info.type = TYPE_COMMENT;
-    info.parent = NULL;
-    info.url = std::string();
     info.name = "コメント";
-    info.data = std::string();
     info.path = path.to_string();
     list_info.push_back( info );
 
@@ -368,7 +585,8 @@ const Gtk::TreePath EditTreeView::create_newcomment( const Gtk::TreePath& path )
     const bool force = false;
     //  append_info 内でundoのコミットをしないで名前を変更してからslot_ren_text_on_canceled()でコミットする
     const bool cancel_undo_commit = true; 
-    append_info( list_info, path, before, scroll, force, cancel_undo_commit );
+    const int check_dup = 0; // 項目の重複チェックをしない
+    append_info( list_info, path, before, scroll, force, cancel_undo_commit, check_dup );
 
     Gtk::TreePath path_new = get_current_path();
     set_cursor( path_new );
@@ -643,7 +861,11 @@ bool EditTreeView::on_drag_drop( const Glib::RefPtr<Gdk::DragContext>& context,
 
     // 共有バッファ内の行を追加
     const bool scroll = false;
-    const CORE::DATA_INFO_LIST list_info = append_info( CORE::SBUF_list_info(), path_dest, before, scroll );
+    const bool force = false;
+    const bool cancel_undo_commit = false;
+    const int check_dup = m_dropped_from_other ? CONFIG::get_check_favorite_dup() : 0;
+
+    const CORE::DATA_INFO_LIST list_info = append_info( CORE::SBUF_list_info(), path_dest, before, scroll, force, cancel_undo_commit, check_dup );
     CORE::SBUF_clear_info();
     if( m_dropped_from_other ) m_sig_dropped_from_other.emit( list_info );
 
@@ -731,6 +953,64 @@ const bool EditTreeView::is_dir( const Gtk::TreePath& path )
 }
 
 
+// 前のディレクトリに移動
+void EditTreeView::prev_dir()
+{
+    Gtk::TreePath path = get_current_path();
+    for(;;){
+        Gtk::TreePath new_path = prev_path( path );
+        if( path == new_path ){
+            goto_top();
+            return;
+        }
+        path = new_path;
+        if( is_dir( path ) ) break;
+    }
+
+    set_cursor( path );
+}
+
+// 次のディレクトリに移動
+void EditTreeView::next_dir()
+{
+    Gtk::TreePath path = get_current_path();
+    for(;;){
+        path = next_path( path );
+        if( ! path.get_depth() || ! get_row( path ) ){
+            goto_bottom();
+            return;
+        }
+        if( is_dir( path ) ) break;
+    }
+
+    set_cursor( path );
+}
+
+
+//
+// 指定したアドレスの行が含まれているか
+//
+const bool EditTreeView::exist_row( const std::string& url, const int type )
+{
+    if( url.empty() ) return false;
+
+    const std::string url_target = get_uptodate_url( url, type );
+
+    SKELETON::EditTreeViewIterator it( *this, m_columns, Gtk::TreePath() );
+    for( ; ! it.end(); ++it ){
+
+        Gtk::TreeModel::Row row = *it;
+
+        const Glib::ustring url_row = row[ m_columns.m_url ];
+        if( ! url_row.empty() ){
+
+            if( url_target == get_uptodate_url( url_row.raw(), row[ m_columns.m_type ] ) ) return true;
+        }
+    }
+
+    return false;
+}
+
 
 //
 // ディレクトリ内を全選択
@@ -762,6 +1042,8 @@ void EditTreeView::select_all_dir( Gtk::TreePath path_dir )
 //
 // cancel_undo_commit = true なら undo バッファをコミットしない
 //
+// check_dup == 0 ならチェックせず追加 1 なら重複チェックをして重複してたらダイアログ表示、2なら重複チェックして重複してたら追加しない
+//
 // (1) path_dest が empty なら一番最後
 //
 // (2) before = true なら path_dest の前
@@ -772,7 +1054,7 @@ void EditTreeView::select_all_dir( Gtk::TreePath path_dir )
 //
 CORE::DATA_INFO_LIST EditTreeView::append_info( const CORE::DATA_INFO_LIST& list_info,
                                                 const Gtk::TreePath& path_dest, const bool before, const bool scroll,
-                                                const bool force, const bool cancel_undo_commit
+                                                const bool force, const bool cancel_undo_commit, int check_dup
     )
 {
     CORE::DATA_INFO_LIST list_info_src;
@@ -784,9 +1066,48 @@ CORE::DATA_INFO_LIST EditTreeView::append_info( const CORE::DATA_INFO_LIST& list
     std::cout << "EditTreeView::append_info"
               << " path_dest = " << path_dest.to_string()
               << " before = " << before
+              << " check_dup = " << check_dup
               << std::endl;
 #endif
 
+    if( ! check_dup ) list_info_src = list_info;
+
+    // 重複がないかチェック
+    else{
+
+#ifdef _DEBUG
+        std::cout << "checking duplicatiion\n";
+#endif        
+
+        CORE::DATA_INFO_LIST::const_iterator it_info = list_info.begin();
+        for( ; it_info != list_info.end(); ++it_info ){
+
+            const CORE::DATA_INFO& info = ( *it_info );
+
+            if( exist_row( info.url, info.type ) ){
+
+                if( check_dup == 2 ) continue;
+
+                SKELETON::MsgCheckDiag mdiag( get_parent_win(),
+                                              info.name + "\n\nは既に含まれています。追加しますか？",
+                                              "今後表示しない(常に追加しない) (_D)",
+                                              Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_YES_NO, Gtk::RESPONSE_NO );
+                mdiag.set_title( "お気に入り追加確認" );
+
+                const int ret = mdiag.run();
+                if( mdiag.get_chkbutton().get_active() ){
+                    CONFIG::set_check_favorite_dup( 2 );
+                    check_dup = 2;
+                }
+                if( ret != Gtk::RESPONSE_YES ) continue;
+            }
+
+            list_info_src.push_back( info );
+        }
+    }
+
+    if( ! list_info_src.size() ) return list_info_src;
+
     if( m_editable && m_undo_buffer ){
         CORE::DATA_INFO_LIST list_info_selected;
         const bool dir = false;
@@ -794,7 +1115,6 @@ CORE::DATA_INFO_LIST EditTreeView::append_info( const CORE::DATA_INFO_LIST& list
         m_undo_buffer->set_list_info_selected( list_info_selected );   // undo したときに選択する列
     }
 
-    list_info_src = list_info;
     replace_infopath( list_info_src, path_dest, before );
     expand_parents( path_dest );
     append_rows( list_info_src );
@@ -872,7 +1192,7 @@ void EditTreeView::delete_path( std::list< Gtk::TreePath >& list_path, const boo
 //
 // 選択した行をまとめて削除
 //
-// force = true なら m_editable が false でも追加
+// force = true なら m_editable が false でも削除
 //
 void EditTreeView::delete_selected_rows( const bool force )
 {
@@ -1182,13 +1502,16 @@ void EditTreeView::get_info_in_selection( CORE::DATA_INFO_LIST& list_info, const
 //
 // ディレクトリ(path_dir)内の行を全てlist_infoにセットする
 //
+// path_dir が empty() ならルートの行を全てセット
+//
 void EditTreeView::get_info_in_dir( CORE::DATA_INFO_LIST& list_info, const Gtk::TreePath& path_dir )
 {
-    if( ! is_dir( path_dir ) ) return;
+    if( ! path_dir.empty() && ! is_dir( path_dir ) ) return;
 
     CORE::DATA_INFO info;
     Gtk::TreePath path = path_dir;
-    path.down();
+    if( path_dir.empty() ) path = Gtk::TreePath( "0" );
+    else path.down();
 
     while( get_row( path ) ){
 
@@ -1223,6 +1546,10 @@ void EditTreeView::path2info( CORE::DATA_INFO& info, const Gtk::TreePath& path )
     info.data = tmp_str.raw();
 
     info.path = path.to_string();
+
+    info.dirid = row[ m_columns.m_dirid ];
+
+    info.expanded = row_expanded( path );
 }
 
 
@@ -1239,7 +1566,7 @@ void EditTreeView::path2info( CORE::DATA_INFO& info, const Gtk::TreePath& path )
 //
 // (4) そうでなければ path_dest の後に追加
 //
-const Gtk::TreePath EditTreeView::append_one_row( const std::string& url, const std::string& name, int type, const std::string& data,
+const Gtk::TreePath EditTreeView::append_one_row( const std::string& url, const std::string& name, const int type, const size_t dirid, const std::string& data,
                                                   const Gtk::TreePath& path_dest, const bool before, const bool subdir )
 {
     Glib::RefPtr< Gtk::TreeStore > treestore = Glib::RefPtr< Gtk::TreeStore >::cast_dynamic( get_model() );
@@ -1260,34 +1587,19 @@ const Gtk::TreePath EditTreeView::append_one_row( const std::string& url, const
     // 前に追加
     else if( before ) row_new = *( treestore->insert( row_dest ) );
 
-    // ディレクトリの下に追加してディレクトリを開く
+    // ディレクトリの下に追加
     else if( subdir && row_dest[ m_columns.m_type ] == TYPE_DIR ){
         row_new = *( treestore->prepend( row_dest.children() ) );
-        expand_row( path_dest, false );
     }
 
     // 後ろに追加
     else row_new = *( treestore->insert_after( row_dest ) );
 
-    // スレ一覧の状態を最新にする
-    std::string url_new = url;
-    if( type == TYPE_BOARD ){
+    // 行のアドレスや状態を最新にする
+    const std::string url_new = get_uptodate_url( url, type );
+    const int type_new = get_uptodate_type( url_new, type );
 
-        url_new = DBTREE::url_boardbase( url );
-
-        if( DBTREE::board_status( url_new ) & STATUS_UPDATE ) type = TYPE_BOARD_UPDATE;
-    }
-
-    // スレ状態を最新にする
-    if( type == TYPE_THREAD || type == TYPE_THREAD_UPDATE || type == TYPE_THREAD_OLD ){
-
-        url_new = DBTREE::url_dat( url );
-
-        if( DBTREE::article_status( url_new ) & STATUS_UPDATE ) type = TYPE_THREAD_UPDATE;
-        if( DBTREE::article_status( url_new ) & STATUS_OLD ) type = TYPE_THREAD_OLD;
-    }
-
-    m_columns.setup_row( row_new, url_new, name, data, type );
+    m_columns.setup_row( row_new, url_new, name, data, type_new, dirid );
 
     return treestore->get_path( row_new );
 }
@@ -1330,6 +1642,10 @@ void EditTreeView::append_rows( const CORE::DATA_INFO_LIST& list_info )
 
     if( ! list_info.size() ) return;
 
+    Gtk::TreePath path_parent;
+    bool expand_parent = false;
+    bool head_info = true;
+
     CORE::DATA_INFO_LIST::const_iterator it = list_info.begin();
     for( ; it != list_info.end(); ++it ){
 
@@ -1355,12 +1671,36 @@ void EditTreeView::append_rows( const CORE::DATA_INFO_LIST& list_info )
 
             // ディレクトリの先頭
             else {
+
                 path.up();
                 subdir = true;
+
+                // 最初の info なら親のディレクトリを開く
+                if( head_info ){
+#ifdef _DEBUG
+                    std::cout << "expand parent dir\n";
+#endif
+                    path_parent = path;
+                    expand_parent = true;
+                }
             }
         }
 
-        append_one_row( info.url, info.name, info.type, info.data, path, before, subdir );
+        append_one_row( info.url, info.name, info.type, info.dirid, info.data, path, before, subdir );
+
+        head_info = false;
+    }
+
+    // ディレクトリを開く
+    if( expand_parent ) expand_row( path_parent, false );
+
+    it = list_info.begin();
+    for( ; it != list_info.end(); ++it ){
+        const CORE::DATA_INFO& info = ( *it );
+        if( info.expanded ){
+            const Gtk::TreePath path( info.path );
+            expand_row( path, false );
+        }
     }
 
     m_updated = true;
@@ -1437,3 +1777,170 @@ void EditTreeView::select_info( const CORE::DATA_INFO_LIST& list_info )
         get_selection()->select( path );
     }
 }
+
+
+
+//
+// ソート実行
+//
+// path : ディレクトリなら中をソート、そうでなければそのレベルでソート
+// mode : ソートのモード。詳しくは class compare_path を参照
+//
+void EditTreeView::sort( const Gtk::TreePath& path, const int mode )
+{
+    if( ! m_editable ) return;
+    if( ! get_row( path ) ) return;
+
+    CORE::DATA_INFO_LIST list_info;
+
+    Gtk::TreePath path_head = path;
+
+    if( is_dir( path_head ) ) path_head.down();
+    else while( path_head.prev() );
+    if( ! get_row( path_head ) ) return;
+    
+    Gtk::TreePath path_parent = path_head;
+    if( path_parent.get_depth() >= 2 ) path_parent.up();
+    else path_parent = Gtk::TreePath();
+
+#ifdef _DEBUG
+    std::cout << "EditTreeView::sort head = " << path_head.to_string() << " parent = " << path_parent.to_string() << std::endl;
+#endif
+
+
+    // ソート
+    std::list< Gtk::TreePath > list_path;
+    Gtk::TreePath path_tmp = path_head;
+    while( get_row( path_tmp ) ){
+
+        list_path.push_back( path_tmp );
+        path_tmp.next();
+    }
+    list_path.sort( compare_path( *this, m_columns, mode ) );
+
+    std::list< Gtk::TreePath >::const_iterator it_path = list_path.begin();
+    for( ; it_path != list_path.end(); ++it_path ){
+
+        const Gtk::TreeRow row = get_row( *it_path );
+        if( row ){
+
+#ifdef _DEBUG
+            std::cout << ( *it_path ).to_string()
+                      << " type = " << row[ m_columns.m_type ]
+                      << " name = " << row[ m_columns.m_name ] << std::endl;
+#endif
+
+            CORE::DATA_INFO info;
+            path2info( info, *it_path );
+            list_info.push_back( info );
+            get_info_in_dir( list_info, *it_path );
+        }
+    }
+
+    // path_parent の中を全て削除
+    if( m_undo_buffer ){
+        CORE::DATA_INFO_LIST list_info_selected;
+        const bool dir = false;
+        get_info_in_selection( list_info_selected, dir );
+        m_undo_buffer->set_list_info_selected( list_info_selected );  // undo したときに選択する列
+    }
+
+    CORE::DATA_INFO_LIST list_info_delete;
+    get_info_in_dir( list_info_delete, path_parent );
+    delete_rows( list_info_delete, Gtk::TreePath() );
+
+    if( m_undo_buffer ){
+        m_undo_buffer->set_list_info( CORE::DATA_INFO_LIST(), list_info_delete );
+    }
+
+    // list_info を path_parent の中に追加
+    const bool before = false;
+    const bool scroll = false;
+    const bool force = false;
+    const bool cancel_undo_commit = false;
+    const int check_dup = 0; // 項目の重複チェックをしない
+    append_info( list_info, path_parent, before, scroll, force, cancel_undo_commit, check_dup );
+
+    set_scroll( path_parent );
+}
+
+
+////////////////////////////////
+
+//
+// EditTreeViewの項目の反復子
+//
+// path から反復開始
+// path が empty の時はルートから反復する
+//
+EditTreeViewIterator::EditTreeViewIterator( EditTreeView& treeview, EditColumns& columns, const Gtk::TreePath path )
+    : m_treeview( treeview ),
+      m_columns( columns ),
+      m_end( false ),
+      m_path( path )
+{
+    const bool root = ( m_path.empty() );
+    if( root ){
+
+        Gtk::TreeModel::Children children = m_treeview.get_model()->children();
+        if( ! children.empty() ) m_path = m_treeview.get_model()->get_path( children.begin() );
+        else{
+            m_end = true;
+            return;
+        }
+    }
+
+    Gtk::TreeModel::Row row = m_treeview.get_row( m_path );
+    if( ! row ) m_end = true;
+    else{
+
+        m_depth = m_path.get_depth();
+        if( ! root ) ++m_depth;
+    }
+}
+
+
+Gtk::TreeModel::Row EditTreeViewIterator::operator * ()
+{
+    return m_treeview.get_row( m_path );
+}
+
+
+void EditTreeViewIterator::operator ++ ()
+{
+    if( m_end ) return;
+
+    Gtk::TreeModel::Row row = m_treeview.get_row( m_path );
+
+    while( 1 ){
+
+        if( row ){
+
+            switch( row[ m_columns.m_type ] ){
+
+                case TYPE_DIR:
+                    m_path.down();
+                    break;
+
+                default:
+                    m_path.next();
+                    break;
+            }
+        }
+
+        else{
+
+            if( m_path.get_depth() > m_depth ){
+                m_path.up();
+                m_path.next();
+            }
+            else{
+                m_end = true;
+                break;
+            }
+        }
+
+        row = m_treeview.get_row( m_path );
+        if( row ) break;
+    }
+}
