@@ -69,11 +69,14 @@ namespace SKELETON
         // 選択中の Gtk::TreeModel::iterator のリストを取得
         std::list< Gtk::TreeModel::iterator > get_selected_iterators();
 
+        // 選択行の削除
+        virtual void delete_selected_rows( const bool force );
+
         // 選択行の移動
         void goto_top();
         void goto_bottom();
-        bool row_up();
-        bool row_down();
+        const bool row_up();
+        const bool row_down();
         void page_up();
         void page_down();
 
